Package: BetaDanish
Type: Package
Title: The Beta-Danish Distribution for Lifetime Data Analysis
Version: 0.2.0
Authors@R: c(
    person("Bilal", "Ahmad", email = "bilalahmad.imcbh9@gmail.com",
           role = c("aut", "cre")),
    person("Muhammad Yameen", "Danish", email = "yameen.danish@aiou.edu.pk", 
           role = "aut")
    )
Description: Implements the four-parameter Beta-Danish distribution and its
    three-parameter submodel for survival and reliability analysis, based on
    Ahmad and Danish (2025) <doi:10.2478/jamsi-2025-0010>. Provides functions
    for density, distribution, quantile, hazard, and random generation.
    Includes maximum likelihood estimation for complete and right-censored
    data, goodness-of-fit assessment, comparison with standard lifetime
    distributions, and publication-quality visualizations. Advanced modules
    support Accelerated Failure Time (AFT) regression, mixture and
    promotion-time cure models, and competing risks analysis.
URL: https://bilal-aiou.github.io/BetaDanish/,
        https://github.com/bilal-aiou/BetaDanish
BugReports: https://github.com/bilal-aiou/BetaDanish/issues
License: GPL-3
Encoding: UTF-8
LazyData: true
Imports: maxLik, survival, stats, graphics, utils, tools
Suggests: readxl, flexsurv, testthat (>= 3.0.0), knitr, rmarkdown,
        cmprsk, coda, MCMCpack
VignetteBuilder: knitr
Config/testthat/edition: 3
Depends: R (>= 3.5)
Config/roxygen2/version: 8.0.0
Language: en-US
NeedsCompilation: no
Packaged: 2026-06-04 01:46:25 UTC; hp
Author: Bilal Ahmad [aut, cre],
  Muhammad Yameen Danish [aut]
Maintainer: Bilal Ahmad <bilalahmad.imcbh9@gmail.com>
Repository: CRAN
Date/Publication: 2026-06-04 02:50:02 UTC
Built: R 4.6.0; ; 2026-06-04 04:20:37 UTC; unix

# Generated by roxygen2: do not edit by hand

S3method(coef,betadanish)
S3method(logLik,betadanish)
S3method(plot,bd_aft)
S3method(plot,bd_cure)
S3method(plot,betadanish)
S3method(print,bd_aft)
S3method(print,bd_bayes)
S3method(print,bd_competing)
S3method(print,bd_cure)
S3method(print,betadanish)
S3method(print,betadanish_report)
S3method(print,summary.bd_aft)
S3method(print,summary.bd_competing)
S3method(print,summary.bd_cure)
S3method(print,summary.betadanish)
S3method(summary,bd_aft)
S3method(summary,bd_competing)
S3method(summary,bd_cure)
S3method(summary,betadanish)
S3method(vcov,betadanish)
export(analyze_betadanish)
export(bayes_betadanish)
export(bd_entropy_shannon)
export(bd_order_stat_pdf)
export(cif_betadanish)
export(cif_compare)
export(compare_distributions)
export(compare_models)
export(dbetadanish)
export(fit_bd_aft)
export(fit_bd_competing)
export(fit_bd_cure)
export(fit_betadanish)
export(gof_betadanish)
export(hbetadanish)
export(pbetadanish)
export(qbetadanish)
export(rbetadanish)
export(read_survival_data)
export(report_betadanish)
export(simulate_bd_cure_data)
export(simulate_bd_data)
importFrom(graphics,abline)
importFrom(graphics,grid)
importFrom(graphics,hist)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,plot)
importFrom(maxLik,maxLik)
importFrom(stats,AIC)
importFrom(stats,BIC)
importFrom(stats,delete.response)
importFrom(stats,logLik)
importFrom(stats,median)
importFrom(stats,model.extract)
importFrom(stats,model.frame)
importFrom(stats,model.response)
importFrom(stats,na.omit)
importFrom(stats,na.pass)
importFrom(stats,optim)
importFrom(stats,pbeta)
importFrom(stats,pchisq)
importFrom(stats,pnorm)
importFrom(stats,qbeta)
importFrom(stats,rbeta)
importFrom(stats,rbinom)
importFrom(stats,rexp)
importFrom(stats,rnorm)
importFrom(stats,rpois)
importFrom(stats,runif)
importFrom(stats,terms)
importFrom(stats,uniroot)
importFrom(stats,var)
importFrom(survival,Surv)
importFrom(survival,is.Surv)
importFrom(survival,survfit)
importFrom(utils,head)
importFrom(utils,packageVersion)
importFrom(utils,tail)

# BetaDanish <a href="https://bilal-aiou.github.io/BetaDanish/"><img src="man/figures/logo.png" align="right" height="139" alt="BetaDanish website" /></a>

<!-- badges: start -->
[![R-CMD-check](https://github.com/bilal-aiou/BetaDanish/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/bilal-aiou/BetaDanish/actions/workflows/R-CMD-check.yaml)
[![pkgdown](https://github.com/bilal-aiou/BetaDanish/actions/workflows/pkgdown.yaml/badge.svg)](https://github.com/bilal-aiou/BetaDanish/actions/workflows/pkgdown.yaml)
[![License: GPL-3](https://img.shields.io/badge/License-GPL--3-blue.svg)](https://www.r-project.org/Licenses/GPL-3)
[![Lifecycle: maturing](https://img.shields.io/badge/lifecycle-maturing-blue.svg)](https://lifecycle.r-lib.org/articles/stages.html)
<!-- badges: end -->

## Overview

The **BetaDanish** package implements the four-parameter Beta-Danish
distribution and its three-parameter Exponentiated Danish (ED)
submodel for survival, reliability, and lifetime-data analysis. The
distribution was introduced by Ahmad and Danish (2025) and offers a
flexible alternative to classical lifetime models such as the
Weibull, gamma, and log-normal, while accommodating monotonic,
unimodal, and bathtub-shaped hazards within a single parametric
family.

Beyond the core distribution, the package provides a comprehensive
toolkit for modern survival modelling:

- Maximum-likelihood and **Bayesian** inference for complete and
  right-censored data
- **Accelerated failure time (AFT)** regression
- Mixture and **promotion-time cure** models
- **Competing risks** analysis with Aalen-Johansen comparisons and
  Gray's test
- Closed-form moments, **Shannon entropy**, order statistics,
  mean residual life, hazard-shape classification, and
  stress-strength reliability
- A complete diagnostic toolkit: survival, hazard, density, P-P, Q-Q
  and **Cox-Snell residual** plots

## Installation

You can install the development version of BetaDanish from
[GitHub](https://github.com/bilal-aiou/BetaDanish) with:

```r
# install.packages("devtools")
devtools::install_github("bilal-aiou/BetaDanish")
```

Optional packages used by advanced modules (declared in `Suggests`):

```r
install.packages(c("MCMCpack", "coda", "cmprsk", "flexsurv", "MASS"))
```

## The Beta-Danish Distribution

### Construction

The Beta-Danish distribution is obtained by applying the
beta-generated family of Eugene, Lee, and Famoye (2002) to the
**Danish baseline**, whose cumulative distribution function and
density are

$$G(z; c, k) = \left(\frac{kz}{1+kz}\right)^c, \qquad g(z; c, k) = ck\,(kz)^{c-1}(1+kz)^{-(c+1)}, \qquad z > 0,$$

with shape parameter $c > 0$ and scale parameter $k > 0$.

### Cumulative distribution function

For a random variable $Z \sim \text{BetaDanish}(a, b, c, k)$ with
$a, b, c, k > 0$, the CDF is the regularised incomplete beta
function evaluated at the Danish CDF:

$$F_Z(z; a, b, c, k) = I_{G(z; c, k)}(a, b) = I_{(kz/(1+kz))^c}(a, b), \qquad z > 0,$$

where $I_x(a, b) = B_x(a, b) / B(a, b)$ and $B(a, b)$ is the beta
function.

### Probability density function

Differentiating the CDF yields the density

$$f_Z(z; a, b, c, k) = \frac{ck}{B(a, b)} \cdot \frac{(kz)^{ca - 1}}{(1 + kz)^{ca + 1}} \cdot \left[1 - \left(\frac{kz}{1 + kz}\right)^c\right]^{b - 1}, \qquad z > 0.$$

The case $a = 1$ yields the three-parameter **Exponentiated Danish
(ED) submodel** used throughout the case studies.

### Survival, hazard, and CDF

The package provides numerically stable d/p/q/r/h functions analogous
to the base R distribution interface:

| Function | Purpose |
|---|---|
| `dbetadanish()` | Density (PDF) |
| `pbetadanish()` | Cumulative distribution (CDF) and survival |
| `qbetadanish()` | Quantile function |
| `rbetadanish()` | Random number generation |
| `hbetadanish()` | Hazard rate |

## Quick Start

```r
library(BetaDanish)

# 1. Evaluate the density, CDF, hazard
dbetadanish(x = 2, a = 1.5, b = 2, c = 3, k = 0.5)
pbetadanish(q = 2, a = 1.5, b = 2, c = 3, k = 0.5)
hbetadanish(x = 2, a = 1.5, b = 2, c = 3, k = 0.5)

# 2. Simulate data and fit a model
set.seed(123)
dat <- simulate_bd_data(n = 200, a = 1.5, b = 2, c = 3, k = 0.5,
                        censor_rate = 0.2)
fit <- fit_betadanish(survival::Surv(time, status) ~ 1, data = dat)
summary(fit)

# 3. Diagnostic plots
plot(fit, type = "all")

# 4. Compare against standard distributions
compare_distributions(fit)
```

## Featured Examples

### Bayesian estimation

```r
data("remission")
fit_bayes <- bayes_betadanish(
  time     = remission$time,
  status   = remission$status,
  submodel = TRUE,
  burnin   = 2000,
  mcmc     = 5000,
  seed     = 1
)
print(fit_bayes)
```

See the **Bayesian Estimation** vignette for full details.

### AFT regression

```r
data("brain_cancer")
fit_aft <- fit_bd_aft(
  survival::Surv(Survtime, Survstatus) ~ Age + Grade + Surgery,
  data = brain_cancer
)
summary(fit_aft)
plot(fit_aft)   # Cox-Snell residual diagnostic
```

### Cure models

Both **mixture** and **promotion-time** cure models on the
Exponentiated Danish kernel:

```r
fit_cure <- fit_bd_cure(
  formula_aft  = survival::Surv(time, status) ~ 1,
  formula_cure = ~ group,
  data         = mydata,
  type         = "mixture"
)
summary(fit_cure)
```

### Competing risks

```r
fit_cr <- fit_bd_competing(time = time, cause = cause)
res <- cif_compare(fit_cr, plot = TRUE)
res$gray_test
```

The fitted Beta-Danish cumulative incidence functions are overlaid
against the nonparametric Aalen-Johansen estimator, with Gray's test
reported for cause equality.

## Structural Properties

| Function | Property |
|---|---|
| `bd_entropy_shannon()` | Shannon (differential) entropy |
| `bd_order_stat_pdf()` | r-th order statistic density |

## Built-in Datasets

| Dataset | n | Description |
|---|---|---|
| `remission` | 128 | Bladder cancer remission times |
| `carbon_fibres` | 100 | Breaking stress of carbon fibres (Gba) |
| `transplant` | 91 | Bone marrow transplant survival |
| `aarset` | 50 | Aarset device failure times (bathtub hazard) |
| `leukemia` | 23 | Acute myelogenous leukemia survival |
| `melanoma` | 205 | Malignant melanoma post-surgery |
| `brain_cancer` | varies | Brain cancer survival with comorbidities |

## Vignettes

The package ships with five comprehensive tutorials:

1. **Introduction to BetaDanish** — Overview, parameterization,
   first-time-user walkthrough
2. **Brain Cancer Case Study** — Complete real-world analysis
3. **Bayesian Estimation** — Posterior inference with
   `bayes_betadanish()`
4. **Competing Risks** — Joint cause-specific modelling with CIF
   comparison
5. **Cure Models** — Mixture and promotion-time formulations

Browse them with:

```r
browseVignettes("BetaDanish")
```

## Citation

If you use BetaDanish in published work, please cite:

> Ahmad, B., & Danish, M. Y. (2025). The Beta-Danish distribution
> for lifetime data analysis. *Journal of Applied Mathematics,
> Statistics and Informatics*, 21(1).
> <https://doi.org/10.2478/jamsi-2025-0010>

A BibTeX entry is available via:

```r
citation("BetaDanish")
```

## References

Ahmad, B., & Danish, M. Y. (2025). The Beta-Danish distribution for
lifetime data analysis. *Journal of Applied Mathematics, Statistics
and Informatics*, 21(1).
<https://doi.org/10.2478/jamsi-2025-0010>

Eugene, N., Lee, C., & Famoye, F. (2002). Beta-normal distribution
and its applications. *Communications in Statistics — Theory and
Methods*, 31(4), 497–512.

## Getting Help

- **Bug reports and feature requests:** please open an issue at
  <https://github.com/bilal-aiou/BetaDanish/issues>
- **Function reference:** see the Reference tab on this site, or
  type `?fit_betadanish` in R
- **Vignettes:** see the Articles tab on this site, or
  `vignette(package = "BetaDanish")`

## Authors

**Bilal Ahmad** *(maintainer)* — Allama Iqbal Open University,
Islamabad, Pakistan. <bilalahmad.imcbh9@gmail.com>

**Muhammad Yameen Danish** — Allama Iqbal Open University,
Islamabad, Pakistan. <yameen.danish@aiou.edu.pk>

## License

GPL-3

## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  fig.width = 7,
  fig.height = 4.5,
  warning = FALSE,
  message = FALSE
)
have_mcmc <- requireNamespace("MCMCpack", quietly = TRUE) &&
             requireNamespace("coda",     quietly = TRUE)
knitr::opts_chunk$set(eval = have_mcmc)

## -----------------------------------------------------------------------------
# library(BetaDanish)
# data("remission")
# fit_bayes <- bayes_betadanish(
#   time     = remission$time,
#   status   = remission$status,
#   submodel = TRUE,
#   burnin   = 2000, mcmc = 5000,
#   tune     = 0.5,
#   seed     = 1
# )
# print(fit_bayes)

## -----------------------------------------------------------------------------
# draws <- fit_bayes$draws
# op <- par(mfrow = c(3, 1), mar = c(3, 4, 2, 1))
# coda::traceplot(draws)
# par(op)

## -----------------------------------------------------------------------------
# post_mean <- summary(draws)$statistics[, "Mean"]
# b <- post_mean["b"]; c <- post_mean["c"]; k <- post_mean["k"]
# km <- survival::survfit(survival::Surv(time, status) ~ 1, data = remission)
# plot(km, conf.int = FALSE, xlab = "Time (months)",
#      ylab = "Survival probability",
#      main = "Posterior mean ED fit on remission data")
# t_grid <- seq(0.1, max(remission$time), length.out = 200)
# S_post <- pbetadanish(t_grid, a = 1, b = b, c = c, k = k,
#                       lower.tail = FALSE)
# lines(t_grid, S_post, col = "red", lwd = 2)
# legend("topright",
#        legend = c("Kaplan-Meier", "Posterior-mean ED"),
#        col = c("black", "red"), lty = 1, lwd = c(1, 2), bty = "n")

## -----------------------------------------------------------------------------
# fit_mle <- fit_betadanish(survival::Surv(time, status) ~ 1,
#                           data = remission, submodel = TRUE,
#                           n_starts = 3)
# cbind(
#   MLE  = round(coef(fit_mle), 4),
#   Bayes_post_mean = round(post_mean, 4)
# )

## ----setup, include = FALSE---------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  fig.width = 7,
  fig.height = 4.5,
  warning = FALSE,
  message = FALSE
)

## ----example------------------------------------------------------------------
library(BetaDanish)
set.seed(2026)
n <- 250
z <- stats::rbinom(n, 1, 0.5)
pi_susc <- stats::plogis(0.3 + 0.7 * z)
cured   <- stats::rbinom(n, 1, 1 - pi_susc) == 1
T_true  <- ifelse(cured, Inf,
                  rbetadanish(n, a = 1, b = 2, c = 1.5, k = 0.4))
C   <- stats::rexp(n, 0.04)
time   <- pmin(T_true, C)
status <- ifelse(T_true <= C, 1, 0)
dat <- data.frame(time = time, status = status, z = z)
cat("Sample size:", n, " Censoring rate:", round(mean(status == 0), 2), "\n")

## ----mix, error = TRUE--------------------------------------------------------
try({
fit_mix <- fit_bd_cure(
  formula_aft  = survival::Surv(time, status) ~ 1,
  formula_cure = ~ z,
  data         = dat,
  type         = "mixture",
  n_starts     = 3
)
summary(fit_mix)
})

## ----prom, error = TRUE-------------------------------------------------------
try({
fit_prom <- fit_bd_cure(
  formula_aft  = survival::Surv(time, status) ~ 1,
  formula_cure = ~ z,
  data         = dat,
  type         = "promotion",
  n_starts     = 3
)
summary(fit_prom)
})

#' Goodness-of-Fit Statistics for Beta-Danish Models
#'
#' Computes Information Criteria (AIC, BIC, HQIC, AICC) and the Kolmogorov-Smirnov 
#' (K-S) statistic for a fitted Beta-Danish model.
#'
#' @param object A fitted `betadanish` object.
#' @return A list containing the Information Criteria and the K-S statistic.
#' @export
gof_betadanish <- function(object) {
  k <- length(object$coefficients)
  n <- length(object$data$time)
  ll <- object$logLik
  
  aic <- 2 * k - 2 * ll
  bic <- k * log(n) - 2 * ll
  hqic <- 2 * k * log(log(n)) - 2 * ll
  aicc <- aic + (2 * k * (k + 1)) / (n - k - 1)
  
  # K-S Statistic using Kaplan-Meier for censored data
  km <- survival::survfit(survival::Surv(object$data$time, object$data$status) ~ 1)
  km_surv <- km$surv
  km_time <- km$time
  
  pars <- as.list(object$coefficients)
  if (object$submodel) pars$a <- 1
  
  fitted_surv <- pbetadanish(km_time, pars$a, pars$b, pars$c, pars$k, lower.tail = FALSE)
  ks_stat <- max(abs(km_surv - fitted_surv), na.rm = TRUE)
  
  list(
    IC = c(AIC = aic, BIC = bic, HQIC = hqic, AICC = aicc),
    KS_Statistic = ks_stat
  )
}

#' Compare Nested Beta-Danish Models
#'
#' Performs a Likelihood Ratio Test (LRT) between the 4-parameter full model 
#' and the 3-parameter submodel.
#'
#' @param full_model A fitted 4-parameter `betadanish` object.
#' @param sub_model A fitted 3-parameter `betadanish` object.
#' @return A data frame with the test statistic and p-value.
#' @export
compare_models <- function(full_model, sub_model) {
  if (full_model$submodel || !sub_model$submodel) {
    stop("Please provide the Full model as the first argument and the Submodel as the second.")
  }
  
  l1 <- full_model$logLik
  l0 <- sub_model$logLik
  
  if (l1 < l0) {
    warning("Full model log-likelihood is lower than submodel. Check convergence.")
  }
  
  test_stat <- max(0, -2 * (l0 - l1))
  p_val <- stats::pchisq(test_stat, df = 1, lower.tail = FALSE)
  
  res <- data.frame(
    Model = c("Submodel (3-param)", "Full Model (4-param)"),
    LogLik = c(l0, l1),
    Chisq = c(NA, test_stat),
    Df = c(NA, 1),
    `Pr(>Chisq)` = c(NA, p_val),
    check.names = FALSE
  )
  
  cat("Likelihood Ratio Test (a = 1 vs a != 1)\n\n")
  print(res, na.print = "")
  return(invisible(res))
}

#' Compare Beta-Danish with Standard Distributions
#'
#' Fits standard lifetime distributions (Weibull, Log-Normal, Log-Logistic, Gamma, 
#' Exponential) using the `flexsurv` package and compares them to the Beta-Danish fit.
#'
#' @param object A fitted `betadanish` object.
#' @return A ranked data frame of model comparisons.
#' @export
compare_distributions <- function(object) {
  if (!requireNamespace("flexsurv", quietly = TRUE)) {
    stop("The 'flexsurv' package is required for this function. Please install it.")
  }
  
  dat <- data.frame(time = object$data$time, status = object$data$status)
  form <- survival::Surv(time, status) ~ 1
  
  # Fit standard models safely
  safe_fit <- function(dist) {
    tryCatch({
      fit <- flexsurv::flexsurvreg(form, data = dat, dist = dist)
      ll <- fit$loglik
      k <- fit$npars
      n <- nrow(dat)
      c(LogLik = ll, AIC = -2*ll + 2*k, BIC = -2*ll + log(n)*k)
    }, error = function(e) c(LogLik = NA, AIC = NA, BIC = NA))
  }
  
  dists <- c("weibull", "lnorm", "llogis", "gamma", "exp")
  names(dists) <- c("Weibull", "Log-Normal", "Log-Logistic", "Gamma", "Exponential")
  
  results <- list()
  
  # Add Beta-Danish
  bd_gof <- gof_betadanish(object)
  results[["Beta-Danish"]] <- c(LogLik = object$logLik, AIC = unname(bd_gof$IC["AIC"]), BIC = unname(bd_gof$IC["BIC"]))
  
  # Add others
  for (nm in names(dists)) {
    results[[nm]] <- safe_fit(dists[nm])
  }
  
  res_df <- do.call(rbind, results)
  res_df <- as.data.frame(res_df)
  res_df$Distribution <- rownames(res_df)
  
  # Rank by AIC
  res_df <- res_df[order(res_df$AIC), c("Distribution", "LogLik", "AIC", "BIC")]
  res_df$Rank <- 1:nrow(res_df)
  rownames(res_df) <- NULL
  
  return(res_df)
}

test_that("gof_betadanish computes IC and KS correctly", {
  set.seed(123)
  dat <- data.frame(time = rbetadanish(30, 1.2, 1.5, 2, 0.5), status = 1)
  fit <- fit_betadanish(survival::Surv(time, status) ~ 1, data = dat, n_starts = 1)

  gof <- gof_betadanish(fit)
  expect_type(gof, "list")
  expect_true(all(c("AIC", "BIC", "HQIC", "AICC") %in% names(gof$IC)))
  expect_true(is.numeric(gof$KS_Statistic))
})

test_that("compare_models performs LRT correctly", {
  set.seed(123)
  dat <- data.frame(time = rbetadanish(40, 1.0, 1.5, 2, 0.5), status = 1)

  fit_full <- fit_betadanish(survival::Surv(time, status) ~ 1, data = dat, submodel = FALSE, n_starts = 1)
  fit_sub <- fit_betadanish(survival::Surv(time, status) ~ 1, data = dat, submodel = TRUE, n_starts = 1)

  res <- compare_models(fit_full, fit_sub)
  expect_s3_class(res, "data.frame")
  expect_equal(nrow(res), 2)
  expect_true("Pr(>Chisq)" %in% colnames(res))
})

#' Read and Prepare Survival Data
#'
#' A helper function to read survival data from CSV or Excel files and prepare
#' it for analysis with the Beta-Danish package. It automatically handles missing
#' status columns by assuming all observations are complete (uncensored).
#'
#' @param file Character string specifying the path to the file.
#' @param time_col Character string specifying the name of the time/survival column.
#' @param status_col Character string specifying the name of the event/censoring
#'   indicator column. If `NULL` (default), the function assumes all observations
#'   are uncensored and creates a status column filled with 1s.
#' @param covar_cols Character vector specifying the names of covariate columns
#'   to keep. If `NULL` (default), no covariates are kept.
#'
#' @return A clean `data.frame` containing the `time`, `status`, and any
#'   specified covariates, ready to be passed to `fit_betadanish()`.
#'
#' @details
#' The function checks the file extension to determine how to read the data.
#' For `.xlsx` or `.xls` files, the `readxl` package must be installed.
#' Missing values (`NA`) in the specified columns will cause those rows to be
#' dropped with a warning.
#'
#' @export
#'
#' @examples
#' tmp <- tempfile(fileext = ".csv")
#' example_data <- data.frame(
#'   survival_time = c(5, 8, 12, 16),
#'   status = c(1, 1, 0, 1)
#' )
#' write.csv(example_data, tmp, row.names = FALSE)
#' dat <- read_survival_data(tmp, time_col = "survival_time", status_col = "status")
#' unlink(tmp)
read_survival_data <- function(file, time_col, status_col = NULL, covar_cols = NULL) {

  if (!file.exists(file)) {
    stop("File not found: ", file)
  }

  # Determine file type and read
  ext <- tolower(tools::file_ext(file))

  if (ext == "csv") {
    dat <- utils::read.csv(file, stringsAsFactors = FALSE)
  } else if (ext %in% c("xls", "xlsx")) {
    if (!requireNamespace("readxl", quietly = TRUE)) {
      stop("The 'readxl' package is required to read Excel files. Please install it.")
    }
    dat <- as.data.frame(readxl::read_excel(file))
  } else {
    stop("Unsupported file extension. Please provide a .csv or .xlsx file.")
  }

  # Validate time column
  if (!time_col %in% colnames(dat)) {
    stop("Time column '", time_col, "' not found in the data.")
  }

  # Validate and handle status column
  if (is.null(status_col)) {
    message("No status column provided. Assuming all observations are uncensored (status = 1).")
    dat$status <- 1
    status_col <- "status"
  } else {
    if (!status_col %in% colnames(dat)) {
      stop("Status column '", status_col, "' not found in the data.")
    }
  }

  # Validate covariates
  if (!is.null(covar_cols)) {
    missing_covars <- setdiff(covar_cols, colnames(dat))
    if (length(missing_covars) > 0) {
      stop("Covariate column(s) not found: ", paste(missing_covars, collapse = ", "))
    }
  }

  # Subset data
  cols_to_keep <- c(time_col, status_col, covar_cols)
  clean_dat <- dat[, cols_to_keep, drop = FALSE]

  # Standardize core column names for easier internal use
  colnames(clean_dat)[1:2] <- c("time", "status")

  # Ensure numeric types
  clean_dat$time <- as.numeric(clean_dat$time)
  clean_dat$status <- as.numeric(clean_dat$status)

  # Handle NAs
  initial_rows <- nrow(clean_dat)
  clean_dat <- stats::na.omit(clean_dat)
  final_rows <- nrow(clean_dat)

  if (final_rows < initial_rows) {
    warning("Dropped ", initial_rows - final_rows, " rows due to missing values (NA).")
  }

  # Validate time and status values
  if (any(clean_dat$time <= 0)) {
    warning("Some time values are <= 0. Survival models typically require strictly positive times.")
  }

  if (!all(clean_dat$status %in% c(0, 1))) {
    stop("Status column contains values other than 0 and 1. Ensure 1 = event, 0 = censored.")
  }

  return(clean_dat)
}

test_that("read_survival_data handles CSVs and missing values", {
  # Create a temporary CSV file
  tmp_file <- tempfile(fileext = ".csv")
  test_data <- data.frame(
    surv_time = c(10, 20, NA, 40),
    event_stat = c(1, 0, 1, 1),
    age = c(50, 60, 70, 80)
  )
  write.csv(test_data, tmp_file, row.names = FALSE)

  # Test reading with covariates
  expect_warning(
    clean_dat <- read_survival_data(tmp_file, time_col = "surv_time", status_col = "event_stat", covar_cols = "age"),
    "Dropped 1 rows due to missing values"
  )

  expect_equal(nrow(clean_dat), 3)
  expect_equal(colnames(clean_dat), c("time", "status", "age"))

  # Test reading without status (assumes all 1s)
  clean_dat2 <- read_survival_data(tmp_file, time_col = "surv_time")
  expect_equal(clean_dat2$status, c(1, 1, 1)) # NA row was dropped

  unlink(tmp_file)
})

#' Fit the Beta-Danish Distribution to Survival Data
#'
#' Fits the Beta-Danish distribution using Maximum Likelihood Estimation (MLE).
#' Supports both complete and right-censored data via `survival::Surv` objects.
#'
#' @param formula A formula object, with the response on the left of a `~` operator,
#'   and the terms on the right. The response must be a survival object as returned
#'   by the `Surv` function. Use `~ 1` for models without covariates.
#' @param data A data frame containing the variables named in the formula.
#' @param submodel Logical; if `TRUE`, fits the 3-parameter submodel by fixing `a = 1`.
#' @param n_starts Integer; the number of random starting points to use for the
#'   optimization to ensure global convergence. Default is 10.
#' @param method Character; the optimization method passed to `maxLik`. Default is "BFGS".
#'
#' @return An object of S3 class `"betadanish"`, containing the parameter estimates,
#'   log-likelihood, variance-covariance matrix, and convergence diagnostics.
#'
#' @details
#' The optimization is performed on the log-transformed parameters to strictly
#' enforce positivity constraints. The returned coefficients and variance-covariance
#' matrix are transformed back to the natural scale using the Delta method.
#'
#' @export
#'
#' @examples
#' \donttest{
#' # Simulate some data
#' set.seed(123)
#' sim_time <- rbetadanish(100, a = 1.5, b = 2, c = 3, k = 0.5)
#' sim_status <- sample(c(0, 1), 100, replace = TRUE, prob = c(0.2, 0.8))
#' dat <- data.frame(time = sim_time, status = sim_status)
#'
#' # Fit the 4-parameter model
#' fit <- fit_betadanish(survival::Surv(time, status) ~ 1, data = dat)
#' summary(fit)
#'
#' # Fit the 3-parameter submodel
#' fit_sub <- fit_betadanish(survival::Surv(time, status) ~ 1, data = dat, submodel = TRUE)
#' summary(fit_sub)
#' }
fit_betadanish <- function(formula, data, submodel = FALSE, n_starts = 10, method = "BFGS") {

  # Extract data
  surv_data <- extract_surv_data(formula, data)
  time <- surv_data$time
  status <- surv_data$status

  # Define Log-Likelihood Function (Optimizing over log-parameters)
  ll_fun <- function(pars) {
    # Extract and transform back to natural scale
    if (submodel) {
      a_par <- 1.0
      b_par <- exp(pars["log_b"])
      c_par <- exp(pars["log_c"])
      k_par <- exp(pars["log_k"])
    } else {
      a_par <- exp(pars["log_a"])
      b_par <- exp(pars["log_b"])
      c_par <- exp(pars["log_c"])
      k_par <- exp(pars["log_k"])
    }

    # Log-PDF for events (uncensored)
    lp <- dbetadanish(time, a_par, b_par, c_par, k_par, log = TRUE)

    # Log-Survival for censored
    ls <- pbetadanish(time, a_par, b_par, c_par, k_par, lower.tail = FALSE, log.p = TRUE)

    # Total Log-Likelihood
    loglik <- sum(status * lp + (1 - status) * ls)

    if (!is.finite(loglik)) return(-1e10)
    return(loglik)
  }

  # Generate Multi-Start Initial Values
  avg_t <- mean(time[status == 1], na.rm = TRUE)
  if (is.na(avg_t) || avg_t <= 0) avg_t <- mean(time, na.rm = TRUE)
  k_base <- 1 / avg_t

  start_list <- list()
  for (i in 1:n_starts) {
    if (submodel) {
      start_list[[i]] <- c(
        log_b = log(stats::runif(1, 0.5, 5)),
        log_c = log(stats::runif(1, 0.5, 5)),
        log_k = log(k_base * stats::runif(1, 0.5, 2))
      )
    } else {
      start_list[[i]] <- c(
        log_a = log(stats::runif(1, 0.5, 5)),
        log_b = log(stats::runif(1, 0.5, 5)),
        log_c = log(stats::runif(1, 0.5, 5)),
        log_k = log(k_base * stats::runif(1, 0.5, 2))
      )
    }
  }

  # Optimize
  fit <- optim_multistart(ll_fun, start_list, method = method)

  if (is.null(fit)) {
    stop("Optimization failed to converge for all starting points.")
  }

  # Transform estimates back to natural scale
  est_log <- fit$estimate
  est_nat <- exp(est_log)
  names(est_nat) <- gsub("log_", "", names(est_log))

  # Transform Variance-Covariance Matrix using Delta Method
  # V_nat = J * V_log * J^T, where J is the Jacobian (diagonal matrix of exp(est_log))
  vcov_log <- tryCatch(solve(-fit$hessian), error = function(e) matrix(NA, length(est_log), length(est_log)))
  J <- diag(est_nat, nrow = length(est_nat))
  vcov_nat <- J %*% vcov_log %*% t(J)
  rownames(vcov_nat) <- colnames(vcov_nat) <- names(est_nat)

  # Construct Output Object
  out <- list(
    coefficients = est_nat,
    logLik = fit$maximum,
    vcov = vcov_nat,
    convergence = fit$code,
    message = fit$message,
    submodel = submodel,
    data = list(time = time, status = status),
    formula = formula,
    call = match.call()
  )

  class(out) <- "betadanish"
  return(out)
}

test_that("fit_betadanish works for complete data", {
  set.seed(42)
  sim_time <- rbetadanish(50, a = 1.5, b = 2.0, c = 1.5, k = 0.5)
  sim_status <- rep(1, 50)
  dat <- data.frame(time = sim_time, status = sim_status)

  # Fit full model
  fit <- fit_betadanish(survival::Surv(time, status) ~ 1, data = dat, n_starts = 2)

  expect_s3_class(fit, "betadanish")
  expect_equal(length(fit$coefficients), 4)
  expect_true(all(fit$coefficients > 0))
  expect_true(is.numeric(fit$logLik))
})

test_that("fit_betadanish works for the 3-parameter submodel", {
  set.seed(42)
  sim_time <- rbetadanish(50, a = 1.0, b = 2.0, c = 1.5, k = 0.5)
  dat <- data.frame(time = sim_time, status = 1)

  fit_sub <- fit_betadanish(survival::Surv(time, status) ~ 1, data = dat, submodel = TRUE, n_starts = 2)

  expect_s3_class(fit_sub, "betadanish")
  expect_equal(length(fit_sub$coefficients), 3)
  expect_true(fit_sub$submodel)
})

test_that("S3 methods return correct structures", {
  set.seed(123)
  dat <- data.frame(time = rbetadanish(30, 1.2, 1.5, 2, 0.5), status = 1)
  fit <- fit_betadanish(survival::Surv(time, status) ~ 1, data = dat, n_starts = 1)

  # Summary
  sum_fit <- summary(fit)
  expect_s3_class(sum_fit, "summary.betadanish")
  expect_true("Pr(>|z|)" %in% colnames(sum_fit$coefficients))

  # logLik
  ll <- logLik(fit)
  expect_s3_class(ll, "logLik")
  expect_equal(attr(ll, "df"), 4)

  # vcov and coef
  expect_equal(dim(vcov(fit)), c(4, 4))
  expect_equal(length(coef(fit)), 4)
})

test_that("plot.betadanish runs without errors", {
  set.seed(123)
  dat <- data.frame(time = rbetadanish(30, 1.2, 1.5, 2, 0.5), status = 1)
  fit <- fit_betadanish(survival::Surv(time, status) ~ 1, data = dat, n_starts = 1)

  # Suppress plot output during testing
  grDevices::pdf(NULL)
  on.exit(grDevices::dev.off())

  expect_silent(plot(fit, type = "survival"))
  expect_silent(plot(fit, type = "hazard"))
  expect_silent(plot(fit, type = "all"))
})

test_that('advanced BetaDanish functions run on example data', {
  skip_on_cran()

  data('remission', package = 'BetaDanish')

  fit <- fit_betadanish(survival::Surv(time, status) ~ 1, data = remission, n_starts = 1)
  expect_s3_class(fit, 'betadanish')

  rep <- report_betadanish(fit)
  expect_s3_class(rep, 'betadanish_report')
  expect_true(is.list(rep))
})

#' @export
print.bd_aft <- function(x, ...) {
  cat("\nCall:\n"); print(x$call)
  cat("\nBeta-Danish AFT Model\n")
  cat("Log-Likelihood:", round(x$logLik, 4), "\n\n")
  cat("Coefficients:\n"); print(round(x$coefficients, 4)); cat("\n")
  invisible(x)
}
#' @export
summary.bd_aft <- function(object, ...) {
  se <- sqrt(pmax(diag(object$vcov), 0))
  z <- object$coefficients / se
  p <- 2 * stats::pnorm(abs(z), lower.tail = FALSE)
  res <- list(call = object$call, coefficients = cbind(Estimate=object$coefficients, `Std. Error`=se, `z value`=z, `Pr(>|z|)`=p), logLik = object$logLik)
  class(res) <- "summary.bd_aft"; return(res)
}
#' @export
print.summary.bd_aft <- function(x, ...) {
  cat("\nCall:\n"); print(x$call)
  cat("\nBeta-Danish AFT Model\n\n")
  stats::printCoefmat(x$coefficients, P.values=TRUE, has.Pvalue=TRUE)
  cat("---\nLog-Likelihood:", round(x$logLik, 4), "\n")
  invisible(x)
}
#' @export
print.bd_cure <- function(x, ...) {
  cat("\nCall:\n"); print(x$call)
  cat("\nBeta-Danish Cure Model (", x$type, ")\n", sep="")
  cat("Log-Likelihood:", round(x$logLik, 4), "\n\n")
  cat("Coefficients:\n"); print(round(x$coefficients, 4)); cat("\n")
  invisible(x)
}
#' @export
summary.bd_cure <- function(object, ...) {
  se <- sqrt(pmax(diag(object$vcov), 0))
  z <- object$coefficients / se
  p <- 2 * stats::pnorm(abs(z), lower.tail = FALSE)
  res <- list(call = object$call, type = object$type, coefficients = cbind(Estimate=object$coefficients, `Std. Error`=se, `z value`=z, `Pr(>|z|)`=p), logLik = object$logLik)
  class(res) <- "summary.bd_cure"; return(res)
}
#' @export
print.summary.bd_cure <- function(x, ...) {
  cat("\nCall:\n"); print(x$call)
  cat("\nBeta-Danish Cure Model (", x$type, ")\n\n", sep="")
  stats::printCoefmat(x$coefficients, P.values=TRUE, has.Pvalue=TRUE)
  cat("---\nLog-Likelihood:", round(x$logLik, 4), "\n")
  invisible(x)
}
#' @export
print.bd_competing <- function(x, ...) {
  cat("\nCall:\n"); print(x$call)
  cat("\nBeta-Danish Competing Risks Model\n")
  cat("Log-Likelihood:", round(x$logLik, 4), "\n\n")
  cat("Coefficients:\n"); print(round(x$coefficients, 4)); cat("\n")
  invisible(x)
}
#' @export
summary.bd_competing <- function(object, ...) {
  res <- list(call = object$call, coefficients = object$coefficients, se = object$se, logLik = object$logLik)
  class(res) <- "summary.bd_competing"; return(res)
}
#' @export
print.summary.bd_competing <- function(x, ...) {
  cat("\nCall:\n"); print(x$call)
  cat("\nBeta-Danish Competing Risks Model\n\n")
  cat("Coefficients:\n"); print(x$coefficients)
  cat("\nStandard Errors:\n"); print(x$se)
  cat("---\nLog-Likelihood:", round(x$logLik, 4), "\n")
  invisible(x)
}

#' @keywords internal
#' @aliases BetaDanish-package
#' 
#' @details 
#' The `BetaDanish` package provides a comprehensive suite of tools for survival 
#' and reliability analysis using the Beta-Danish distribution. It includes core 
#' mathematical functions (density, distribution, quantile, random generation, 
#' and hazard), robust Maximum Likelihood Estimation (MLE) for both complete and 
#' right-censored data, and advanced modeling capabilities including Accelerated 
#' Failure Time (AFT) regression, cure-rate models, and competing risks analysis.
#' 
#' @references
#' Ahmad, B. (2026). Modeling Diverse Survival Patterns: The Development and 
#' Characterization of a New Four-Parameter Lifetime Distribution (Ph.D. Thesis). 
#' Allama Iqbal Open University, Islamabad.
#' 
#' @importFrom maxLik maxLik
#' @importFrom survival Surv survfit is.Surv
#' @importFrom stats AIC BIC logLik optim pbeta qbeta rbeta runif pnorm pchisq model.extract model.frame model.response delete.response terms na.omit na.pass median var rnorm rbinom rpois rexp uniroot
#' @importFrom graphics lines plot legend grid abline hist
#' @importFrom utils head tail packageVersion
"_PACKAGE"

if (getRversion() >= "2.15.1") {
  utils::globalVariables(c(
    "time", "status", "group", "cause", "cif", "type", "Model", "S", 
    "Param", "Bias", "Estimate", "Lower", "Upper", "post_cure"
  ))
}

#' Create a compact report from a BetaDanish model fit
#'
#' @param fit A fitted BetaDanish model object.
#' @return A list containing model summary information.
#' @export
report_betadanish <- function(fit) {
  if (is.null(fit)) stop('fit must be a fitted BetaDanish object')

  out <- list(
    call = fit$call,
    coefficients = fit$coefficients,
    logLik = fit$logLik,
    AIC = fit$AIC,
    BIC = fit$BIC,
    convergence = fit$convergence
  )

  class(out) <- 'betadanish_report'
  out
}

#' @export
print.betadanish_report <- function(x, ...) {
  cat('BetaDanish Model Report\n')
  cat('-----------------------\n')
  if (!is.null(x$AIC)) cat('AIC:', x$AIC, '\n')
  if (!is.null(x$BIC)) cat('BIC:', x$BIC, '\n')
  if (!is.null(x$logLik)) cat('Log-likelihood:', x$logLik, '\n')
  if (!is.null(x$convergence)) cat('Convergence:', x$convergence, '\n')
  invisible(x)
}

#' Plot Diagnostics for Beta-Danish Fit
#'
#' Generates diagnostic plots for a fitted Beta-Danish model, including survival,
#' hazard, density, PP, and QQ plots.
#'
#' @param x A fitted `betadanish` object.
#' @param type Character string specifying the plot type: `"survival"`, `"hazard"`,
#'   `"density"`, `"pp"`, `"qq"`, or `"all"`.
#'
#' @return Invisibly returns the input betadanish object. Called mainly for its side effect of producing diagnostic plots.
#' @param ... Additional arguments passed to the base `plot` function.
#' @export
plot.betadanish <- function(x, type = c("survival", "hazard", "density", "pp", "qq", "all"), ...) {
  type <- match.arg(type)

  time <- x$data$time
  status <- x$data$status
  time_max <- max(time, na.rm = TRUE)
  seq_t <- seq(1e-5, time_max, length.out = 200)

  pars <- as.list(x$coefficients)
  if (x$submodel) pars$a <- 1

  # Helper to reset par if "all" is chosen
  old_par <- graphics::par(no.readonly = TRUE)
  if (type == "all") {
    graphics::par(mfrow = c(2, 3))
    on.exit(graphics::par(old_par))
  }

  plot_types <- if (type == "all") c("survival", "hazard", "density", "pp", "qq") else type

  for (pt in plot_types) {
    if (pt == "survival") {
      km <- survival::survfit(survival::Surv(time, status) ~ 1)
      graphics::plot(km, conf.int = FALSE, xlab = "Time", ylab = "Survival Probability",
                     main = "Survival Fit: Beta-Danish vs KM", ...)
      fit_probs <- pbetadanish(seq_t, pars$a, pars$b, pars$c, pars$k, lower.tail = FALSE)
      graphics::lines(seq_t, fit_probs, col = "red", lwd = 2)
      graphics::legend("topright", legend = c("Kaplan-Meier", "Beta-Danish"),
                       col = c("black", "red"), lty = 1, lwd = c(1, 2), bty = "n")

    } else if (pt == "hazard") {
      haz_vals <- hbetadanish(seq_t, pars$a, pars$b, pars$c, pars$k)
      graphics::plot(seq_t, haz_vals, type = "l", col = "blue", lwd = 2,
                     xlab = "Time", ylab = "Hazard Rate",
                     main = "Estimated Hazard Function", ...)
      graphics::grid()

    } else if (pt == "density") {
      # Density plot makes most sense for uncensored data, but we plot it anyway
      graphics::hist(time[status == 1], probability = TRUE, breaks = 20,
                     col = "lightgray", border = "white",
                     xlab = "Time", main = "Density Fit (Events Only)", ...)
      pdf_vals <- dbetadanish(seq_t, pars$a, pars$b, pars$c, pars$k)
      graphics::lines(seq_t, pdf_vals, col = "darkgreen", lwd = 2)

    } else if (pt == "pp") {
      # PP Plot (Empirical CDF vs Fitted CDF)
      km <- survival::survfit(survival::Surv(time, status) ~ 1)
      emp_cdf <- 1 - km$surv
      fit_cdf <- pbetadanish(km$time, pars$a, pars$b, pars$c, pars$k)
      graphics::plot(fit_cdf, emp_cdf, xlab = "Theoretical Probabilities",
                     ylab = "Empirical Probabilities", main = "P-P Plot", pch = 16, col = "blue", ...)
      graphics::abline(0, 1, col = "red", lwd = 2)

    } else if (pt == "qq") {
      # QQ Plot (Empirical Quantiles vs Fitted Quantiles)
      km <- survival::survfit(survival::Surv(time, status) ~ 1)
      emp_cdf <- 1 - km$surv
      # Avoid 1.0 for quantile function
      emp_cdf[emp_cdf >= 1] <- 0.9999
      fit_q <- qbetadanish(emp_cdf, pars$a, pars$b, pars$c, pars$k)
      graphics::plot(fit_q, km$time, xlab = "Theoretical Quantiles",
                     ylab = "Empirical Quantiles", main = "Q-Q Plot", pch = 16, col = "blue", ...)
      graphics::abline(0, 1, col = "red", lwd = 2)
    }
  }
  invisible(x)
}

#' Fit Beta-Danish Competing Risks Model
#'
#' Fits a parametric competing risks model assuming independent latent failure
#' times, where each cause-specific baseline follows a 4-parameter Beta-Danish
#' distribution.
#'
#' @param time Numeric vector of observed times.
#' @param cause Integer vector of event causes. `0` indicates right-censored,
#'   and `1, 2, ..., m` indicate specific event causes.
#' @param n_starts Integer; number of random starts for the joint optimization.
#' @param method Optimization method passed to `maxLik`.
#'
#' @return An object of class `bd_competing`.
#'
#' @details
#' Under the assumption of independent latent failure times, the joint likelihood
#' factorizes. The function first fits independent Beta-Danish models for each
#' cause (treating other causes as censored) to find robust starting values,
#' then optimizes the joint likelihood.
#'
#' @export
fit_bd_competing <- function(time, cause, n_starts = 5, method = "BFGS") {

  if (length(time) != length(cause)) stop("time and cause must have the same length.")

  causes <- sort(unique(cause[cause > 0]))
  m <- length(causes)
  if (m < 2) stop("Competing risks analysis requires at least 2 distinct event causes.")

  # 1. Cause-wise initialization
  init_list <- list()
  for (j in causes) {
    # Treat cause j as event (1), everything else as censored (0)
    status_j <- ifelse(cause == j, 1, 0)

    # Fit single-cause model to get starting values
    # We use a small number of starts here to save time
    dat_j <- data.frame(time = time, status = status_j)
    fit_j <- fit_betadanish(survival::Surv(time, status) ~ 1, data = dat_j, n_starts = 3)

    init_list[[paste0("cause", j)]] <- log(fit_j$coefficients)
  }

  joint_start <- unlist(init_list)

  # 2. Joint Log-Likelihood
  ll_joint <- function(pars) {
    ll_total <- 0

    for (idx in seq_along(causes)) {
      j <- causes[idx]

      # Extract parameters for cause j
      p_idx <- ((idx - 1) * 4 + 1):(idx * 4)
      p_j <- exp(pars[p_idx])
      a <- p_j[1]; b <- p_j[2]; c <- p_j[3]; k <- p_j[4]

      # Times for events of cause j
      tj <- time[cause == j]
      # Times for everything else (censored for cause j)
      tc <- time[cause != j]

      if (length(tj) > 0) {
        log_f <- dbetadanish(tj, a, b, c, k, log = TRUE)
        ll_total <- ll_total + sum(log_f)
      }
      if (length(tc) > 0) {
        log_S <- pbetadanish(tc, a, b, c, k, lower.tail = FALSE, log.p = TRUE)
        ll_total <- ll_total + sum(log_S)
      }
    }

    if (!is.finite(ll_total)) return(-1e10)
    return(ll_total)
  }

  # 3. Joint Optimization with jittered starts
  start_list_joint <- list(joint_start)
  if (n_starts > 1) {
    for (i in 2:n_starts) {
      start_list_joint[[i]] <- joint_start + stats::rnorm(length(joint_start), 0, 0.2)
    }
  }

  fit <- optim_multistart(ll_joint, start_list_joint, method = method)
  if (is.null(fit)) stop("Competing risks optimization failed to converge.")

  # 4. Format Output
  est_log <- fit$estimate
  est_nat <- exp(est_log)

  # Reshape into a matrix
  par_matrix <- matrix(est_nat, nrow = m, ncol = 4, byrow = TRUE)
  colnames(par_matrix) <- c("a", "b", "c", "k")
  rownames(par_matrix) <- paste0("Cause_", causes)

  # Vcov via Delta method
  vcov_log <- tryCatch(solve(-fit$hessian), error = function(e) matrix(NA, length(est_log), length(est_log)))
  J <- diag(est_nat, nrow = length(est_nat))
  vcov_nat <- J %*% vcov_log %*% t(J)

  se_matrix <- matrix(sqrt(pmax(diag(vcov_nat), 0)), nrow = m, ncol = 4, byrow = TRUE)
  colnames(se_matrix) <- c("SE_a", "SE_b", "SE_c", "SE_k")
  rownames(se_matrix) <- paste0("Cause_", causes)

  out <- list(
    coefficients = par_matrix,
    se = se_matrix,
    logLik = fit$maximum,
    vcov = vcov_nat,
    convergence = fit$code,
    causes = causes,
    data = list(time = time, cause = cause),
    call = match.call(),
    submodel = FALSE
  )
  class(out) <- "bd_competing"
  return(out)
}

#' Compute Cumulative Incidence Function (CIF)
#'
#' Computes the CIF for a specific cause from a fitted Beta-Danish competing
#' risks model using numerical integration.
#'
#' @param fit An object of class `bd_competing`.
#' @param tvec Numeric vector of times at which to evaluate the CIF.
#' @param cause_idx Integer; the specific cause to evaluate (must match one of
#'   the causes in the fitted model).
#'
#' @return A numeric vector of CIF probabilities corresponding to `tvec`.
#' @export
cif_betadanish <- function(fit, tvec, cause_idx) {
  if (!inherits(fit, "bd_competing")) stop("fit must be a bd_competing object.")
  if (!(cause_idx %in% fit$causes)) stop("cause_idx not found in fitted model.")

  m <- length(fit$causes)
  pm <- fit$coefficients

  # Map cause_idx to row index
  row_idx <- which(fit$causes == cause_idx)

  res <- numeric(length(tvec))

  for (i in seq_along(tvec)) {
    t_val <- tvec[i]
    if (t_val <= 0) {
      res[i] <- 0
      next
    }

    # Integrand: h_j(u) * S_overall(u) = f_j(u) * prod_{l != j} S_l(u)
    integrand <- function(u) {
      # Density of cause of interest
      p_j <- pm[row_idx, ]
      f_j <- dbetadanish(u, p_j["a"], p_j["b"], p_j["c"], p_j["k"], log = FALSE)

      # Survival of other causes
      S_other <- rep(1, length(u))
      for (l in 1:m) {
        if (l != row_idx) {
          p_l <- pm[l, ]
          S_other <- S_other * pbetadanish(u, p_l["a"], p_l["b"], p_l["c"], p_l["k"], lower.tail = FALSE)
        }
      }
      return(f_j * S_other)
    }

    # Integrate from 0 to t_val
    int_res <- tryCatch({
      stats::integrate(integrand, lower = 0, upper = t_val, subdivisions = 2000, rel.tol = 1e-6)$value
    }, error = function(e) NA_real_)

    res[i] <- int_res
  }

  return(res)
}

#' Fit Beta-Danish AFT Regression Model
#'
#' Fits an Accelerated Failure Time (AFT) regression model using the
#' Complementary Exponentiated Danish (CED) baseline (Beta-Danish with a=1).
#'
#' @param formula A survival formula (e.g., `Surv(time, status) ~ age + treatment`).
#' @param data A data frame containing the variables.
#' @param n_starts Integer; number of random starts for optimization.
#' @param method Optimization method passed to `maxLik`.
#'
#' @return An object of class `bd_aft`.
#'
#' @details
#' To ensure identifiability, the shape parameter `a` is fixed to 1. The scale
#' parameter `k` is linked to covariates via `k_i = exp(X_i %*% delta)`.
#' Positive coefficients in `delta` indicate a larger `k`, which corresponds
#' to shorter survival times (accelerated failure).
#'
#' @export
fit_bd_aft <- function(formula, data, n_starts = 10, method = "BFGS") {

  # Extract data
  surv_data <- extract_surv_data(formula, data)
  time <- surv_data$time
  status <- surv_data$status
  X <- surv_data$X

  # Define Log-Likelihood
  ll_fun <- function(pars) {
    log_b <- pars[1]
    log_c <- pars[2]
    delta <- pars[3:length(pars)]

    b <- exp(log_b)
    c <- exp(log_c)

    # k_i = exp(X %*% delta)
    eta_k <- as.numeric(X %*% delta)
    k_i <- exp(eta_k)

    # PDF and Survival
    log_f <- dbetadanish(time, a = 1, b = b, c = c, k = k_i, log = TRUE)
    log_S <- pbetadanish(time, a = 1, b = b, c = c, k = k_i, lower.tail = FALSE, log.p = TRUE)

    ll <- sum(status * log_f + (1 - status) * log_S)
    if (!is.finite(ll)) return(-1e10)
    return(ll)
  }

  # Multi-start initialization
  avg_t <- mean(time[status == 1], na.rm = TRUE)
  if (is.na(avg_t) || avg_t <= 0) avg_t <- mean(time, na.rm = TRUE)

  start_list <- list()
  for (i in 1:n_starts) {
    init_delta <- rep(0, ncol(X))
    init_delta[1] <- log(1 / avg_t) + stats::rnorm(1, 0, 0.5) # Jitter intercept

    start_list[[i]] <- c(
      log_b = log(stats::runif(1, 0.5, 3)),
      log_c = log(stats::runif(1, 0.5, 3)),
      init_delta
    )
    names(start_list[[i]])[3:length(start_list[[i]])] <- paste0("delta_", colnames(X))
  }

  # Optimize
  fit <- optim_multistart(ll_fun, start_list, method = method)
  if (is.null(fit)) stop("AFT optimization failed to converge.")

  # Extract and format results
  est <- fit$estimate
  vcov_mat <- tryCatch(solve(-fit$hessian), error = function(e) matrix(NA, length(est), length(est)))
  rownames(vcov_mat) <- colnames(vcov_mat) <- names(est)

  out <- list(
    coefficients = est,
    logLik = fit$maximum,
    vcov = vcov_mat,
    convergence = fit$code,
    data = list(time = time, status = status, X = X),
    formula = formula,
    call = match.call(),
    submodel = TRUE
  )
  class(out) <- "bd_aft"
  return(out)
}

#' Comprehensive Beta-Danish Analysis Pipeline
#'
#' Runs a complete end-to-end analysis: reads data, fits the 4-parameter and
#' 3-parameter models, compares them, benchmarks against standard distributions,
#' and generates diagnostic plots.
#'
#' @param file Path to the CSV or Excel file containing the data.
#' @param time_col Name of the time column.
#'
#' @return Invisibly returns a list containing the fitted full model and submodel objects. The function is mainly called for its side effects of printing an analysis report and producing diagnostic plots.
#' @param status_col Name of the status column (optional).
#' @export
analyze_betadanish <- function(file, time_col, status_col = NULL) {
  cat("======================================================\n")
  cat("       BETA-DANISH COMPREHENSIVE ANALYSIS REPORT      \n")
  cat("======================================================\n\n")

  # 1. Read Data
  cat("[1] Reading Data...\n")
  dat <- read_survival_data(file, time_col, status_col)
  cat("    Successfully loaded", nrow(dat), "observations.\n\n")

  # 2. Fit Models
  cat("[2] Fitting Models...\n")
  form <- survival::Surv(time, status) ~ 1

  cat("    Fitting Full 4-Parameter Model...\n")
  fit_full <- fit_betadanish(form, data = dat, submodel = FALSE)

  cat("    Fitting 3-Parameter Submodel (a=1)...\n")
  fit_sub <- fit_betadanish(form, data = dat, submodel = TRUE)

  # 3. Print Summaries
  cat("\n[3] Model Summaries:\n")
  print(summary(fit_full))

  # 4. Compare Nesting
  cat("\n[4] Nested Model Comparison:\n")
  compare_models(fit_full, fit_sub)

  # 5. Compare Distributions
  if (requireNamespace("flexsurv", quietly = TRUE)) {
    cat("\n[5] Benchmarking Against Standard Distributions:\n")
    comp_tab <- compare_distributions(fit_full)
    print(comp_tab, row.names = FALSE)
  } else {
    cat("\n[5] Benchmarking skipped (install 'flexsurv' to enable).\n")
  }

  # 6. Plotting
  cat("\n[6] Generating Diagnostic Plots...\n")
  plot(fit_full, type = "all")

  cat("\n======================================================\n")
  cat("                  ANALYSIS COMPLETE                   \n")
  cat("======================================================\n")

  invisible(list(full_model = fit_full, sub_model = fit_sub))
}

#' Robust Multi-Start Optimization using maxLik
#'
#' @param ll_fun Log-likelihood function to maximize
#' @param start_list A list of named numeric vectors for starting values
#' @param method Optimization method (default "BFGS")
#'
#' @return The best fitted maxLik object, or NULL if all fail
#' @noRd
optim_multistart <- function(ll_fun, start_list, method = "BFGS") {
  best_fit <- NULL
  best_ll <- -Inf

  for (start_vals in start_list) {
    fit <- tryCatch({
      maxLik::maxLik(logLik = ll_fun, start = start_vals, method = method)
    }, error = function(e) NULL)

    # Check if fit was successful and yielded a valid log-likelihood
    if (!is.null(fit) && !is.na(fit$maximum) && is.finite(fit$maximum)) {
      if (fit$maximum > best_ll) {
        best_ll <- fit$maximum
        best_fit <- fit
      }
    }
  }

  return(best_fit)
}

#' Log-Space Addition
#' Computes log(exp(x) + exp(y)) stably
#' @noRd
logspace_add <- function(logx, logy) {
  m <- pmax(logx, logy)
  m + log(exp(logx - m) + exp(logy - m))
}

#' Simulate Data from the Beta-Danish Distribution
#'
#' Generates synthetic survival data from the Beta-Danish distribution, with
#' optional right-censoring.
#'
#' @param n Integer; number of observations to simulate.
#' @param a,b,c,k Numeric; parameters of the Beta-Danish distribution.
#' @param censor_rate Numeric; rate parameter for the exponential censoring
#'   distribution. If `0` (default), no censoring is applied.
#' @param seed Integer; optional seed for reproducibility.
#'
#' @return A data frame with columns `time` and `status`.
#' @export
#'
#' @examples
#' # Simulate complete data
#' dat <- simulate_bd_data(n = 100, a = 1.5, b = 2, c = 3, k = 0.5)
#'
#' # Simulate censored data
#' dat_cens <- simulate_bd_data(n = 100, a = 1.5, b = 2, c = 3, k = 0.5, censor_rate = 0.1)
simulate_bd_data <- function(n, a, b, c, k, censor_rate = 0, seed = NULL) {
  if (!is.null(seed)) set.seed(seed)

  # Generate true event times
  true_times <- rbetadanish(n, a, b, c, k)

  if (censor_rate > 0) {
    # Generate censoring times from Exponential distribution
    censor_times <- stats::rexp(n, rate = censor_rate)

    # Observed time is the minimum of true time and censoring time
    time <- pmin(true_times, censor_times)
    status <- ifelse(true_times <= censor_times, 1, 0)
  } else {
    time <- true_times
    status <- rep(1, n)
  }

  data.frame(time = time, status = status)
}

#' Simulate Beta-Danish Cure Data
#'
#' Generates synthetic survival data from a Beta-Danish mixture or promotion-time
#' cure model, incorporating covariates.
#'
#' @param n Integer; number of observations.
#' @param type Character; `"mixture"` or `"promotion"`.
#' @param a,b,c Numeric; baseline shape parameters.
#' @param delta Numeric vector; coefficients for the latency scale `k`.
#' @param gamma Numeric vector; coefficients for the incidence/cure component.
#' @param X Matrix; design matrix for latency (must match length of `delta`).
#' @param Z Matrix; design matrix for incidence (must match length of `gamma`).
#' @param target_censor Numeric; target proportion of censoring to calibrate the
#'   exponential censoring rate. Default is 0.3.
#' @param seed Integer; optional seed.
#'
#' @return A list containing the simulated `data` (time, status), the `cured`
#'   indicator, and the true parameters.
#' @export
simulate_bd_cure_data <- function(n, type = c("mixture", "promotion"), a = 1, b = 2, c = 1.5,
                                  delta, gamma, X, Z, target_censor = 0.3, seed = NULL) {
  type <- match.arg(type)
  if (!is.null(seed)) set.seed(seed)

  # Latency scale
  eta_k <- as.numeric(X %*% delta)
  k_i <- exp(eta_k)

  T_true <- rep(Inf, n)
  cured <- rep(FALSE, n)

  if (type == "mixture") {
    # Susceptible probability
    eta_pi <- as.numeric(Z %*% gamma)
    pi_i <- 1 / (1 + exp(-eta_pi))

    cured <- stats::rbinom(n, 1, prob = 1 - pi_i) == 1

    # Generate times for susceptible
    n_sus <- sum(!cured)
    if (n_sus > 0) {
      T_true[!cured] <- rbetadanish(n_sus, a, b, c, k_i[!cured])
    }

  } else {
    # Promotion-time
    eta_th <- as.numeric(Z %*% gamma)
    theta_i <- exp(eta_th)

    # Number of clonogenic cells
    N_cells <- stats::rpois(n, lambda = theta_i)
    cured <- (N_cells == 0)

    for (i in which(!cured)) {
      # Time is the minimum of N_cells latent times
      latent_times <- rbetadanish(N_cells[i], a, b, c, k_i[i])
      T_true[i] <- min(latent_times)
    }
  }

  # Calibrate censoring to hit target_censor
  finite_T <- T_true[is.finite(T_true)]
  if (length(finite_T) > 10) {
    obj_fun <- function(rate) {
      C <- stats::rexp(length(finite_T), rate)
      mean(C < finite_T) - target_censor
    }
    opt_rate <- tryCatch(stats::uniroot(obj_fun, c(1e-6, 10))$root, error = function(e) 0.05)
  } else {
    opt_rate <- 0.05
  }

  C_times <- stats::rexp(n, rate = opt_rate)
  time <- pmin(T_true, C_times)
  status <- ifelse(T_true <= C_times, 1, 0)

  list(
    data = data.frame(time = time, status = status),
    cured = cured,
    true_params = list(a=a, b=b, c=c, delta=delta, gamma=gamma)
  )
}

#' Fit Beta-Danish Cure Models
#'
#' Fits mixture and promotion-time (non-mixture) cure models using the 
#' Beta-Danish AFT baseline.
#'
#' @param formula_aft A formula for the latency component (e.g., `Surv(time, status) ~ age`).
#' @param formula_cure A one-sided formula for the incidence/cure component (e.g., `~ treatment`).
#' @param data A data frame containing the variables.
#' @param type Character; either `"mixture"` or `"promotion"`.
#' @param n_starts Integer; number of random starts for optimization.
#' @param method Optimization method passed to `maxLik`.
#'
#' @return An object of class `bd_cure`.
#'
#' @details
#' In the **mixture** model, the population is split into susceptible and cured 
#' fractions. The susceptible probability is modeled via logistic regression: 
#' `pi = exp(Z %*% gamma) / (1 + exp(Z %*% gamma))`.
#' 
#' In the **promotion-time** (non-mixture) model, the cure fraction is derived 
#' from a latent Poisson process of clonogenic cells: `theta = exp(Z %*% gamma)`. 
#' The cure fraction is `exp(-theta)`.
#'
#' @export
fit_bd_cure <- function(formula_aft, formula_cure, data, type = c("mixture", "promotion"), n_starts = 10, method = "BFGS") {
  type <- match.arg(type)
  
  # Ensure complete cases across both formulas
  vars_needed <- unique(c(all.vars(formula_aft), all.vars(formula_cure)))
  data <- data[stats::complete.cases(data[, vars_needed, drop = FALSE]), , drop = FALSE]
  
  # Extract data
  surv_data <- extract_surv_data(formula_aft, data)
  time <- surv_data$time
  status <- surv_data$status
  X <- surv_data$X # Latency covariates
  
  # Extract cure covariates from the ORIGINAL data
  mf_cure <- stats::model.frame(formula_cure, data, na.action = stats::na.pass)
  Z <- stats::model.matrix(formula_cure, mf_cure)
  
  # Define Log-Likelihood
  ll_fun <- function(pars) {
    log_b <- pars[1]
    log_c <- pars[2]
    delta <- pars[3:(2 + ncol(X))]
    gamma <- pars[(3 + ncol(X)):length(pars)]
    
    b <- exp(log_b)
    c <- exp(log_c)
    
    # Latency scale
    k_i <- exp(as.numeric(X %*% delta))
    
    # Baseline functions
    log_f <- dbetadanish(time, a = 1, b = b, c = c, k = k_i, log = TRUE)
    log_S <- pbetadanish(time, a = 1, b = b, c = c, k = k_i, lower.tail = FALSE, log.p = TRUE)
    F_u <- pbetadanish(time, a = 1, b = b, c = c, k = k_i, lower.tail = TRUE, log.p = FALSE)
    
    if (type == "mixture") {
      # pi = susceptible proportion
      eta_pi <- as.numeric(Z %*% gamma)
      log_pi <- -log1p(exp(-eta_pi))       # log(pi)
      log_1m_pi <- -log1p(exp(eta_pi))     # log(1 - pi)
      
      # Event: log(pi * f)
      ll_event <- log_pi + log_f
      
      # Censored: log((1 - pi) + pi * S)
      ll_cens <- logspace_add(log_1m_pi, log_pi + log_S)
      
      ll <- sum(status * ll_event + (1 - status) * ll_cens)
      
    } else {
      # Promotion-time
      theta_i <- exp(as.numeric(Z %*% gamma))
      
      # Event: log(theta * f * exp(-theta * F))
      ll_event <- log(theta_i) + log_f - theta_i * F_u
      
      # Censored: log(exp(-theta * F))
      ll_cens <- -theta_i * F_u
      
      ll <- sum(status * ll_event + (1 - status) * ll_cens)
    }
    
    if (!is.finite(ll)) return(-1e10)
    return(ll)
  }
  
  # Multi-start initialization
  km <- survival::survfit(survival::Surv(time, status) ~ 1)
  km_tail <- max(min(utils::tail(km$surv, 1), 0.99), 0.01)
  
  start_list <- list()
  for (i in 1:n_starts) {
    init_delta <- rep(0, ncol(X))
    init_delta[1] <- log(1 / mean(time)) + stats::rnorm(1, 0, 0.5)
    
    init_gamma <- rep(0, ncol(Z))
    if (type == "mixture") {
      init_gamma[1] <- stats::qlogis(1 - km_tail) # Susceptible proportion
    } else {
      init_gamma[1] <- log(-log(km_tail))
    }
    
    start_list[[i]] <- c(
      log_b = log(stats::runif(1, 0.5, 3)),
      log_c = log(stats::runif(1, 0.5, 3)),
      init_delta,
      init_gamma
    )
    names(start_list[[i]])[3:(2 + ncol(X))] <- paste0("delta_", colnames(X))
    names(start_list[[i]])[(3 + ncol(X)):length(start_list[[i]])] <- paste0("gamma_", colnames(Z))
  }
  
  # Optimize
  fit <- optim_multistart(ll_fun, start_list, method = method)
  if (is.null(fit)) stop("Cure model optimization failed to converge.")
  
  est <- fit$estimate
  vcov_mat <- tryCatch(solve(-fit$hessian), error = function(e) matrix(NA, length(est), length(est)))
  rownames(vcov_mat) <- colnames(vcov_mat) <- names(est)
  
  out <- list(
    coefficients = est,
    logLik = fit$maximum,
    vcov = vcov_mat,
    convergence = fit$code,
    type = type,
    data = list(time = time, status = status, X = X, Z = Z),
    formula_aft = formula_aft,
    formula_cure = formula_cure,
    call = match.call(),
    submodel = TRUE
  )
  class(out) <- "bd_cure"
  return(out)
}

#' Bladder Cancer Remission Times
#'
#' Remission times (in months) for 128 bladder cancer patients. This is a
#' complete (uncensored) sample widely used in lifetime distribution literature
#' to demonstrate decreasing or right-skewed hazard rates.
#'
#' @format A data frame with 128 rows and 2 columns:
#' \describe{
#'   \item{time}{Remission time in months}
#'   \item{status}{Event indicator (1 = event occurred)}
#' }
#' @source Lee, E. T., & Wang, J. W. (2003). Statistical Methods for Survival Data Analysis (3rd ed.). Wiley.
#' @examples
#' data(remission)
#' \donttest{
#' fit <- fit_betadanish(survival::Surv(time, status) ~ 1, data = remission)
#' summary(fit)
#' }
"remission"

#' Breaking Stress of Carbon Fibres
#'
#' Breaking stress (in Gba) of 100 carbon fibre specimens. This dataset exhibits
#' a unimodal (increasing-then-decreasing) hazard pattern that classical
#' distributions like the Weibull cannot adequately capture.
#'
#' @format A data frame with 100 rows and 2 columns:
#' \describe{
#'   \item{time}{Breaking stress in Gba}
#'   \item{status}{Event indicator (1 = event occurred)}
#' }
#' @source Nichols, M. D., & Padgett, W. J. (2006). A bootstrap control chart for Weibull percentiles. Quality and Reliability Engineering International, 22(2), 141-151.
#' @examples
#' data(carbon_fibres)
#' \donttest{
#' fit <- fit_betadanish(survival::Surv(time, status) ~ 1, data = carbon_fibres)
#' }
"carbon_fibres"

#' Bone Marrow Transplant Survival
#'
#' Survival times for 91 patients with refractory acute lymphoblastic leukemia
#' who received either an allogeneic or autologous bone marrow transplant.
#' This dataset includes right-censoring and a treatment covariate, making it
#' ideal for demonstrating cure-rate models and AFT regression.
#'
#' @format A data frame with 91 rows and 3 columns:
#' \describe{
#'   \item{time}{Survival time in days}
#'   \item{status}{Event indicator (1 = death/relapse, 0 = censored)}
#'   \item{group}{Treatment group (0 = Allogeneic, 1 = Autologous)}
#' }
#' @source Klein, J. P., & Moeschberger, M. L. (2003). Survival Analysis: Techniques for Censored and Truncated Data (2nd ed.). Springer.
#' @examples
#' data(transplant)
#' \donttest{
#' # Fit a model with a covariate
#' fit <- fit_bd_aft(survival::Surv(time, status) ~ group, data = transplant)
#' }
"transplant"

#' Aarset Device Failure Times
#'
#' Times to failure of 50 devices, exhibiting a classic bathtub-shaped hazard rate.
#' This is a standard benchmark dataset in reliability engineering.
#'
#' @format A data frame with 50 rows and 2 columns:
#' \describe{
#'   \item{time}{Failure time}
#'   \item{status}{Event indicator (1 = event occurred)}
#' }
#' @source Aarset, M. V. (1987). How to Identify a Bathtub Hazard Rate. IEEE Transactions on Reliability, R-36(1), 106-108.
#' @examples
#' data(aarset)
#' \donttest{
#' fit <- fit_betadanish(survival::Surv(time, status) ~ 1, data = aarset)
#' plot(fit, type = "hazard")
#' }
"aarset"

#' Acute Myelogenous Leukemia Survival
#'
#' Survival times (in weeks) for 23 patients with acute myelogenous leukemia.
#' A classic, small dataset perfect for fast testing of censored data workflows.
#'
#' @format A data frame with 23 rows and 3 columns:
#' \describe{
#'   \item{time}{Survival time in weeks}
#'   \item{status}{Event indicator (1 = event, 0 = censored)}
#'   \item{group}{Treatment group (Maintained vs Non-maintained)}
#' }
#' @source Miller, R. G. (1997). Survival Analysis. Wiley.
#' @examples
#' data(leukemia)
#' fit <- fit_betadanish(survival::Surv(time, status) ~ 1, data = leukemia)
"leukemia"

#' Malignant Melanoma Survival After Surgery
#'
#' Survival times for 205 patients with malignant melanoma after surgery.
#' This rich clinical dataset includes multiple covariates and heavy censoring.
#'
#' @format A data frame with 205 rows and 6 columns:
#' \describe{
#'   \item{time}{Survival time in days}
#'   \item{status}{Event indicator (1 = died from melanoma, 0 = alive, 2 = other death)}
#'   \item{thickness}{Tumor thickness in mm}
#'   \item{sex}{Patient sex (1 = male, 0 = female)}
#'   \item{age}{Patient age in years}
#'   \item{ulcer}{Ulceration indicator (1 = present, 0 = absent)}
#'   \item{year}{Year of operation}
#' }
#' @source Andersen, P. K., Borgan, O., Gill, R. D., & Keiding, N. (1993). Statistical Models Based on Counting Processes. Springer.
#' @examples
#' data(melanoma)
#' \donttest{
#' # Treat status 1 as event, others as censored
#' melanoma$event <- ifelse(melanoma$status == 1, 1, 0)
#' fit <- fit_betadanish(survival::Surv(time, event) ~ age + thickness, data = melanoma)
#' }
"melanoma"
#' Brain Cancer Survival Data
#'
#' A comprehensive dataset of 500 brain cancer patients, including survival times,
#' censoring status, and multiple clinical covariates. This dataset was used to
#' demonstrate Accelerated Failure Time (AFT) regression and Cure-Rate models
#' using the Beta-Danish distribution.
#'
#' @format A data frame with 500 rows and 16 columns:
#' \describe{
#'   \item{ID}{Patient identifier}
#'   \item{Gender}{Patient gender (1 = Male, 0 = Female)}
#'   \item{Age}{Age group (1 = Young, 2 = Middle, 3 = Old)}
#'   \item{Area}{Geographic area (1 = Urban, 0 = Rural)}
#'   \item{FH}{Family history of cancer (1 = Yes, 0 = No)}
#'   \item{CMH}{Comorbid history (1 = Yes, 0 = No)}
#'   \item{Grade}{Tumor grade (1 = I/II, 2 = III, 3 = IV)}
#'   \item{Surgery}{Surgical intervention (1 = Yes, 0 = No)}
#'   \item{Radiotherapy}{Radiotherapy treatment (1 = Yes, 0 = No)}
#'   \item{Chemotherapy}{Chemotherapy treatment (1 = Yes, 0 = No)}
#'   \item{Treatment}{Treatment type}
#'   \item{Morphology}{Tumor morphology}
#'   \item{Survstatus}{Survival status (1 = Event/Death, 0 = Censored)}
#'   \item{Survtime}{Survival time in months}
#'   \item{Types}{Tumor types classification}
#'   \item{Morphology1}{Alternative morphology classification}
#' }
#' @source Atomic Energy Cancer Hospital (NORI), Islamabad, Pakistan.
#' @examples
#' data(brain_cancer)
#' \donttest{
#' # Fit an AFT model using the brain cancer data
#' fit <- fit_bd_aft(survival::Surv(Survtime, Survstatus) ~ Age + Grade + Surgery,
#'                   data = brain_cancer, n_starts = 2)
#' summary(fit)
#' }
"brain_cancer"

#' Extract Survival Data from Formula
#'
#' @param formula A survival formula (e.g., Surv(time, status) ~ 1)
#' @param data A data frame
#'
#' @return A list containing `time`, `status`, and `covariates` (if any)
#' @noRd
extract_surv_data <- function(formula, data) {
  if (missing(data)) {
    data <- environment(formula)
  }

  mf <- stats::model.frame(formula, data, na.action = stats::na.omit)
  Y <- stats::model.extract(mf, "response")

  if (!survival::is.Surv(Y)) {
    stop("The response must be a 'Surv' object. Example: Surv(time, status) ~ 1")
  }

  time <- Y[, 1]
  status <- Y[, 2] # 1 = event, 0 = censored

  # Extract covariates if present (excluding intercept)
  X <- stats::model.matrix(stats::terms(formula), mf)

  list(
    time = time,
    status = status,
    X = X,
    data_frame = mf
  )
}

#' Validate Beta-Danish Parameters
#'
#' @param a,b,c,k Numeric parameters
#' @return Logical TRUE if valid, FALSE otherwise
#' @noRd
check_positive_params <- function(a, b, c, k) {
  if (any(is.na(c(a, b, c, k)))) return(FALSE)
  if (any(c(a, b, c, k) <= 0)) return(FALSE)
  TRUE
}

#' The Beta-Danish Distribution
#'
#' Density, distribution function, quantile function, hazard function, and
#' random generation for the four-parameter Beta-Danish distribution.
#'
#' @param x,q Vector of quantiles (time points).
#' @param p Vector of probabilities.
#' @param n Number of observations to generate.
#' @param a Shape parameter (beta generator). Set `a = 1` for the 3-parameter submodel.
#' @param b Shape parameter (beta generator / tail weight).
#' @param c Shape parameter (baseline shape).
#' @param k Scale parameter (baseline scale).
#' @param log,log.p Logical; if TRUE, probabilities/densities are given as log.
#' @param lower.tail Logical; if TRUE (default), probabilities are P[X <= x], otherwise P[X > x].
#'
#' @details
#' The Beta-Danish distribution is a highly flexible lifetime distribution capable
#' of modeling decreasing, increasing, unimodal, and bathtub-shaped hazard rates.
#'
#' @return
#' `dbetadanish` gives the density, `pbetadanish` gives the distribution function,
#' `qbetadanish` gives the quantile function, `hbetadanish` gives the hazard function,
#' and `rbetadanish` generates random deviates.
#'
#' @references
#' Ahmad, B., & Danish, M. Y. (2026). Development and Characterization of a
#' Flexible Three-Parameter Lifetime Distribution.
#'
#' @examples
#' # Density
#' dbetadanish(x = 2, a = 1.5, b = 2, c = 3, k = 0.5)
#'
#' # CDF
#' pbetadanish(q = 2, a = 1.5, b = 2, c = 3, k = 0.5)
#'
#' # Hazard
#' hbetadanish(x = 2, a = 1.5, b = 2, c = 3, k = 0.5)
#'
#' # Random generation
#' rbetadanish(n = 10, a = 1.5, b = 2, c = 3, k = 0.5)
#'
#' @name BetaDanish
NULL

#' @rdname BetaDanish
#' @export
dbetadanish <- function(x, a, b, c, k, log = FALSE) {
  if (!check_positive_params(a, b, c, k)) {
    warning("Parameters a, b, c, and k must be strictly positive.")
    return(rep(NaN, length(x)))
  }

  # Log-space calculations for numerical stability
  log_k <- log(k)
  log_x <- suppressWarnings(log(x))
  log_1_plus_kx <- log1p(k * x)

  # Baseline G(x) = (kx / (1 + kx))^c
  log_u <- log_k + log_x - log_1_plus_kx
  log_G <- c * log_u

  # Baseline density g(x) = c * k * (kx)^(c-1) / (1 + kx)^(c+1)
  log_g <- log(c) + log_k + (c - 1) * log_u - 2 * log_1_plus_kx

  # Beta-Danish PDF: f(x) = g(x) * G(x)^(a-1) * (1 - G(x))^(b-1) / B(a,b)
  G <- exp(log_G)
  G[G >= 1] <- 1 - 1e-16
  log_1_minus_G <- log1p(-G) # Stably computes log(1 - G)

  log_pdf <- log_g + (a - 1) * log_G + (b - 1) * log_1_minus_G - lbeta(a, b)

  # Boundary handling
  log_pdf[x <= 0] <- -Inf

  if (log) return(log_pdf)
  return(exp(log_pdf))
}

#' @rdname BetaDanish
#' @export
pbetadanish <- function(q, a, b, c, k, lower.tail = TRUE, log.p = FALSE) {
  if (!check_positive_params(a, b, c, k)) return(rep(NaN, length(q)))

  q[q < 0] <- 0

  # Baseline G(q)
  u <- (k * q) / (1 + k * q)
  G_q <- u^c

  # F(x) = I_{G(x)}(a, b) = pbeta(G(x), a, b)
  p <- stats::pbeta(G_q, shape1 = a, shape2 = b, lower.tail = lower.tail, log.p = log.p)
  return(p)
}

#' @rdname BetaDanish
#' @export
qbetadanish <- function(p, a, b, c, k, lower.tail = TRUE, log.p = FALSE) {
  if (!check_positive_params(a, b, c, k)) return(rep(NaN, length(p)))

  # Invert the Beta generator
  y <- stats::qbeta(p, shape1 = a, shape2 = b, lower.tail = lower.tail, log.p = log.p)

  # Invert the baseline: G(x) = y  =>  x = y^(1/c) / (k * (1 - y^(1/c)))
  y_c <- y^(1/c)
  x <- y_c / (k * (1 - y_c))

  return(x)
}

#' @rdname BetaDanish
#' @export
rbetadanish <- function(n, a, b, c, k) {
  if (!check_positive_params(a, b, c, k)) stop("Parameters must be positive.")
  u <- stats::runif(n)
  qbetadanish(u, a, b, c, k)
}

#' @rdname BetaDanish
#' @export
hbetadanish <- function(x, a, b, c, k, log = FALSE) {
  log_pdf <- dbetadanish(x, a, b, c, k, log = TRUE)
  log_surv <- pbetadanish(x, a, b, c, k, lower.tail = FALSE, log.p = TRUE)

  log_surv[log_surv == -Inf] <- -700
  log_haz <- log_pdf - log_surv

  if (log) return(log_haz)
  return(exp(log_haz))
}

test_that("PDF integrates to 1 (Unity Check)", {
  # Full 4-parameter model
  int_full <- stats::integrate(
    f = function(x) dbetadanish(x, a = 1.5, b = 2.0, c = 3.0, k = 0.5),
    lower = 0, upper = Inf
  )
  expect_equal(int_full$value, 1.0, tolerance = 1e-4)

  # 3-parameter submodel (a = 1)
  int_sub <- stats::integrate(
    f = function(x) dbetadanish(x, a = 1.0, b = 2.5, c = 1.5, k = 1.0),
    lower = 0, upper = Inf
  )
  expect_equal(int_sub$value, 1.0, tolerance = 1e-4)
})

test_that("CDF matches numerical integration of PDF", {
  x_test <- 2.0
  a <- 2.0; b <- 1.5; c <- 2.0; k <- 0.5

  cdf_analytical <- pbetadanish(x_test, a, b, c, k)
  cdf_numerical <- stats::integrate(
    f = function(t) dbetadanish(t, a, b, c, k),
    lower = 0, upper = x_test
  )$value

  expect_equal(cdf_analytical, cdf_numerical, tolerance = 1e-5)
})

test_that("Quantile function perfectly inverts the CDF", {
  probs <- c(0.1, 0.5, 0.9)
  a <- 1.2; b <- 0.8; c <- 1.5; k <- 0.2

  quantiles <- qbetadanish(probs, a, b, c, k)
  cdf_back <- pbetadanish(quantiles, a, b, c, k)

  expect_equal(cdf_back, probs, tolerance = 1e-5)
})

test_that("Hazard function equals PDF / Survival", {
  x_test <- 1.5
  a <- 1.5; b <- 2.0; c <- 1.2; k <- 0.8

  haz_analytical <- hbetadanish(x_test, a, b, c, k)
  pdf_val <- dbetadanish(x_test, a, b, c, k)
  surv_val <- pbetadanish(x_test, a, b, c, k, lower.tail = FALSE)

  expect_equal(haz_analytical, pdf_val / surv_val, tolerance = 1e-5)
})

test_that("Invalid parameters return NaN and warnings", {
  expect_warning(res <- dbetadanish(1, a = -1, b = 2, c = 3, k = 0.5))
  expect_true(is.nan(res))
})

#' Print Method for Beta-Danish Fit
#'
#' @param x An object of class `betadanish`.
#'
#' @return Invisibly returns the input betadanish object. Called mainly for its side effect of printing the fitted model summary.
#' @param ... Further arguments passed to or from other methods.
#' @export
print.betadanish <- function(x, ...) {
  cat("\nCall:\n")
  print(x$call)
  cat("\nBeta-Danish Distribution Fit\n")
  cat("Model:", if(x$submodel) "3-Parameter Submodel (a=1)" else "Full 4-Parameter Model", "\n")
  cat("Log-Likelihood:", round(x$logLik, 4), "\n\n")
  cat("Coefficients:\n")
  print(round(x$coefficients, 4))
  cat("\n")
  invisible(x)
}

#' Summary Method for Beta-Danish Fit
#'
#' @param object An object of class `betadanish`.
#'
#' @return An object of class summary.betadanish containing coefficient estimates, standard errors, test statistics, p-values, log-likelihood, and model selection criteria.
#' @param ... Further arguments passed to or from other methods.
#' @export
summary.betadanish <- function(object, ...) {
  est <- object$coefficients
  se <- sqrt(pmax(diag(object$vcov), 0))
  z_val <- est / se
  p_val <- 2 * stats::pnorm(abs(z_val), lower.tail = FALSE)

  lower_95 <- est - 1.96 * se
  upper_95 <- est + 1.96 * se

  coef_table <- cbind(
    Estimate = est,
    `Std. Error` = se,
    `Lower 95%` = lower_95,
    `Upper 95%` = upper_95,
    `z value` = z_val,
    `Pr(>|z|)` = p_val
  )

  rownames(coef_table) <- names(est)

  k <- length(est)
  n <- length(object$data$time)
  aic <- 2 * k - 2 * object$logLik
  bic <- k * log(n) - 2 * object$logLik

  res <- list(
    call = object$call,
    submodel = object$submodel,
    coefficients = coef_table,
    logLik = object$logLik,
    aic = aic,
    bic = bic,
    convergence = object$convergence
  )

  class(res) <- "summary.betadanish"
  return(res)
}

#' Print Summary Method for Beta-Danish Fit
#'
#' @param x An object of class `summary.betadanish`.
#'
#' @return Invisibly returns the input summary.betadanish object. Called mainly for its side effect of printing the coefficient table and fit statistics.
#' @param ... Further arguments passed to or from other methods.
#' @export
print.summary.betadanish <- function(x, ...) {
  cat("\nCall:\n")
  print(x$call)
  cat("\nBeta-Danish Distribution Fit\n")
  cat("Model:", if(x$submodel) "3-Parameter Submodel (a=1)" else "Full 4-Parameter Model", "\n\n")

  stats::printCoefmat(x$coefficients, P.values = TRUE, has.Pvalue = TRUE)

  cat("---\n")
  cat("Log-Likelihood:", round(x$logLik, 4), "\n")
  cat("AIC:", round(x$aic, 4), " | BIC:", round(x$bic, 4), "\n")

  if (x$convergence != 0) {
    cat("\nWarning: Optimization may not have converged (Code:", x$convergence, ")\n")
  }
  invisible(x)
}

#' Extract Log-Likelihood
#'
#' @param object An object of class `betadanish`.
#'
#' @return An object of class logLik containing the maximized log-likelihood value, with degrees of freedom and number of observations stored as attributes.
#' @param ... Further arguments passed to or from other methods.
#' @export
logLik.betadanish <- function(object, ...) {
  val <- object$logLik
  attr(val, "df") <- length(object$coefficients)
  attr(val, "nobs") <- length(object$data$time)
  class(val) <- "logLik"
  return(val)
}

#' Extract Variance-Covariance Matrix
#'
#' @param object An object of class `betadanish`.
#'
#' @return A numeric variance-covariance matrix for the estimated model parameters.
#' @param ... Further arguments passed to or from other methods.
#' @export
vcov.betadanish <- function(object, ...) {
  return(object$vcov)
}

#' Extract Coefficients
#'
#' @param object An object of class `betadanish`.
#'
#' @return A named numeric vector of maximum likelihood parameter estimates.
#' @param ... Further arguments passed to or from other methods.
#' @export
coef.betadanish <- function(object, ...) {
  return(object$coefficients)
}

---
title: "Cure Models with the Beta-Danish Distribution"
author: "Bilal Ahmad"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Cure Models with the Beta-Danish Distribution}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r setup, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  fig.width = 7,
  fig.height = 4.5,
  warning = FALSE,
  message = FALSE
)
```

## Two cure formulations

The package implements two cure formulations on the Exponentiated Danish
kernel:

- **Mixture cure** splits the population into a susceptible fraction
  `pi(Z)` modelled by logistic regression on the incidence covariates,
  and a cured fraction `1 - pi(Z)`.
- **Promotion-time cure** derives the cure fraction from a latent
  Poisson process of clonogenic cells with intensity
  `theta(Z) = exp(Z' gamma)`; the cure fraction is `exp(-theta(Z))`.

Both are fitted via `fit_bd_cure()`.

## Quick example

Both fits below use simulated data with a known cure structure.

```{r example}
library(BetaDanish)
set.seed(2026)
n <- 250
z <- stats::rbinom(n, 1, 0.5)
pi_susc <- stats::plogis(0.3 + 0.7 * z)
cured   <- stats::rbinom(n, 1, 1 - pi_susc) == 1
T_true  <- ifelse(cured, Inf,
                  rbetadanish(n, a = 1, b = 2, c = 1.5, k = 0.4))
C   <- stats::rexp(n, 0.04)
time   <- pmin(T_true, C)
status <- ifelse(T_true <= C, 1, 0)
dat <- data.frame(time = time, status = status, z = z)
cat("Sample size:", n, " Censoring rate:", round(mean(status == 0), 2), "\n")
```

## Mixture cure model

```{r mix, error = TRUE}
fit_mix <- fit_bd_cure(
  formula_aft  = survival::Surv(time, status) ~ 1,
  formula_cure = ~ z,
  data         = dat,
  type         = "mixture",
  n_starts     = 3
)
summary(fit_mix)
```

## Promotion-time cure model

```{r prom, error = TRUE}
fit_prom <- fit_bd_cure(
  formula_aft  = survival::Surv(time, status) ~ 1,
  formula_cure = ~ z,
  data         = dat,
  type         = "promotion",
  n_starts     = 3
)
summary(fit_prom)
```

## See also

- `?fit_bd_cure` for full documentation
- `?bd_bootstrap_ci` for bootstrap confidence intervals
- `?plot.bd_cure` for Cox-Snell residual plots

---
title: "Competing Risks with the Beta-Danish Distribution"
author: "Bilal Ahmad"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Competing Risks with the Beta-Danish Distribution}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r setup, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  fig.width = 7,
  fig.height = 4.5,
  warning = FALSE,
  message = FALSE
)
have_cmprsk <- requireNamespace("cmprsk", quietly = TRUE)
knitr::opts_chunk$set(eval = have_cmprsk)
```

## Overview

Under independent latent failure times, the joint competing-risks
likelihood factorises into one Beta-Danish marginal per cause. This
vignette demonstrates fitting and diagnostic plotting.

If `cmprsk` is not installed, code chunks below are skipped.

## Simulated two-cause data

```{r data}
library(BetaDanish)
set.seed(2026)
n  <- 400
T1 <- rbetadanish(n, a = 1.2, b = 1.5, c = 1.0, k = 0.4)
T2 <- rbetadanish(n, a = 1.0, b = 2.0, c = 1.0, k = 0.2)
C  <- stats::rexp(n, 0.05)
time  <- pmin(T1, T2, C)
cause <- ifelse(time == C, 0L, ifelse(T1 <= T2, 1L, 2L))
table(cause)
```

## Fitting the model

```{r fit}
fit <- fit_bd_competing(time = time, cause = cause)
print(fit)
```

## CIF comparison: Beta-Danish vs Aalen-Johansen

```{r cif}
res <- cif_compare(fit, plot = TRUE)
```

## Gray's test

```{r gray}
if (!is.null(res$gray_test)) {
  print(res$gray_test)
} else {
  cat("Gray's test was not produced.\n")
}
```

---
title: "A Case Study Using the Beta-Danish Distribution"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{A Case Study Using the Beta-Danish Distribution}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(collapse = TRUE, comment = '#>')
```

# Introduction

This vignette demonstrates a typical survival analysis workflow using the BetaDanish package.

```{r}
library(BetaDanish)
library(survival)
data('remission', package = 'BetaDanish')
head(remission)
```

# Fitting the Beta-Danish model

```{r}
fit <- fit_betadanish(Surv(time, status) ~ 1, data = remission, n_starts = 1)
summary(fit)
```

# Three-parameter submodel

```{r}
fit_sub <- fit_betadanish(Surv(time, status) ~ 1, data = remission, submodel = TRUE, n_starts = 1)
compare_models(fit, fit_sub)
```

# Diagnostic plots

```{r, fig.width = 7, fig.height = 5}
plot(fit, type = 'survival')
plot(fit, type = 'hazard')
```

# Interpretation

The fitted model can be used to estimate survival probabilities, hazard behavior, and overall model fit. Users should compare the Beta-Danish model with alternative lifetime distributions and inspect diagnostic plots before drawing final conclusions.

---
title: "Bayesian Estimation with BetaDanish"
author: "Bilal Ahmad"
date: "`r Sys.Date()`"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Bayesian Estimation with BetaDanish}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  fig.width = 7,
  fig.height = 4.5,
  warning = FALSE,
  message = FALSE
)
have_mcmc <- requireNamespace("MCMCpack", quietly = TRUE) &&
             requireNamespace("coda",     quietly = TRUE)
knitr::opts_chunk$set(eval = have_mcmc)
```

## 1. Overview

This vignette walks through Bayesian estimation of the three-parameter
Exponentiated Danish (ED) submodel and the full four-parameter
Beta-Danish distribution using `bayes_betadanish()`.

## 2. ED submodel on bladder cancer remission times

```{r}
library(BetaDanish)
data("remission")
fit_bayes <- bayes_betadanish(
  time     = remission$time,
  status   = remission$status,
  submodel = TRUE,
  burnin   = 2000, mcmc = 5000,
  tune     = 0.5,
  seed     = 1
)
print(fit_bayes)
```

## 3. Posterior diagnostics

```{r}
draws <- fit_bayes$draws
op <- par(mfrow = c(3, 1), mar = c(3, 4, 2, 1))
coda::traceplot(draws)
par(op)
```

## 4. Posterior survival vs Kaplan-Meier

```{r}
post_mean <- summary(draws)$statistics[, "Mean"]
b <- post_mean["b"]; c <- post_mean["c"]; k <- post_mean["k"]
km <- survival::survfit(survival::Surv(time, status) ~ 1, data = remission)
plot(km, conf.int = FALSE, xlab = "Time (months)",
     ylab = "Survival probability",
     main = "Posterior mean ED fit on remission data")
t_grid <- seq(0.1, max(remission$time), length.out = 200)
S_post <- pbetadanish(t_grid, a = 1, b = b, c = c, k = k,
                      lower.tail = FALSE)
lines(t_grid, S_post, col = "red", lwd = 2)
legend("topright",
       legend = c("Kaplan-Meier", "Posterior-mean ED"),
       col = c("black", "red"), lty = 1, lwd = c(1, 2), bty = "n")
```

## 5. Bayesian vs MLE comparison

```{r}
fit_mle <- fit_betadanish(survival::Surv(time, status) ~ 1,
                          data = remission, submodel = TRUE,
                          n_starts = 3)
cbind(
  MLE  = round(coef(fit_mle), 4),
  Bayes_post_mean = round(post_mean, 4)
)
```

---
title: "Introduction to the BetaDanish Package"
author: "Bilal Ahmad & Dr. Muhammad Yameen Danish"
date: "`r Sys.Date()`"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Introduction to the BetaDanish Package}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  warning = FALSE,
  message = FALSE
)
```

## 1. Introduction

The **`BetaDanish`** package provides a comprehensive suite of tools for survival and reliability analysis using the Beta-Danish distribution.

Classical lifetime models, such as the Weibull, Gamma, or Log-Normal distributions, are often limited in their hazard shape flexibility. They typically force the hazard rate to be strictly monotonic or, at best, unimodal. The Beta-Danish distribution overcomes these limitations by accommodating **decreasing, increasing, unimodal (upside-down bathtub), and bathtub-shaped** hazard rates within a single, unified four-parameter family.

This package implements the core mathematical functions, robust Maximum Likelihood Estimation (MLE) for complete and right-censored data, and advanced modules for Accelerated Failure Time (AFT) regression, cure-rate models, and competing risks.

## 2. Theoretical Background

The Beta-Danish distribution is constructed by applying the beta-generated transformation (Eugene et al., 2002) to a baseline distribution. The baseline used here is the two-parameter exponentiated log-logistic distribution.

Let $a, b, c, k > 0$ be the parameters of the distribution. 
* $k$ is the **scale parameter**.
* $c$ is the **baseline shape parameter**.
* $a$ and $b$ are the **beta-generator shape parameters** controlling skewness and tail weight.

The Cumulative Distribution Function (CDF) is given by the regularized incomplete beta function:
$$ F(t) = I_{G(t)}(a, b) $$
where $G(t) = \left( \frac{k t}{1 + k t} \right)^c$.

The Probability Density Function (PDF) is:
$$ f(t) = \frac{c k}{B(a, b)} \frac{(k t)^{ca - 1}}{(1 + k t)^{ca + 1}} \left[ 1 - \left( \frac{k t}{1 + k t} \right)^c \right]^{b - 1} $$

### The 3-Parameter Submodel
By fixing $a = 1$, the distribution reduces to a highly tractable 3-parameter submodel (the Complementary Exponentiated Danish distribution), which is particularly useful for regression and cure-rate modeling to ensure parameter identifiability.

## 3. Core Distribution Functions

The package provides the standard `d/p/q/r/h` functions. All internal calculations are performed in log-space to ensure numerical stability, especially in the tails.

```r
library(BetaDanish)

# Calculate the hazard rate at time t = 2
hbetadanish(x = 2, a = 1.5, b = 2.0, c = 3.0, k = 0.5)

# Generate 100 random survival times
set.seed(2026)
sim_data <- rbetadanish(n = 100, a = 1.5, b = 2.0, c = 3.0, k = 0.5)
```

## 4. Fitting Models to Data

The `fit_betadanish()` function is the core MLE engine. It uses a multi-start optimization strategy to ensure global convergence and strictly enforces positivity constraints via log-scale reparameterization.

### Example 1: Uncensored Data (Bladder Cancer Remission)

The `remission` dataset contains the remission times of 128 bladder cancer patients. This data exhibits a unimodal/decreasing hazard rate.

```r
# Load the built-in dataset
data("remission", package = "BetaDanish")

# Fit the full 4-parameter model
fit_full <- fit_betadanish(survival::Surv(time, status) ~ 1, data = remission)
summary(fit_full)

# Fit the 3-parameter submodel (a = 1)
fit_sub <- fit_betadanish(survival::Surv(time, status) ~ 1, data = remission, submodel = TRUE)

# Compare the nested models using a Likelihood Ratio Test (LRT)
compare_models(fit_full, fit_sub)
```

You can easily generate publication-quality diagnostic plots:

```r
# Generates Survival, Hazard, Density, P-P, and Q-Q plots
plot(fit_full, type = "all")
```

### Example 2: Right-Censored Data (Bone Marrow Transplant)

The `transplant` dataset contains survival times for 91 patients, including right-censored observations. The `fit_betadanish()` function natively handles `survival::Surv` objects.

```r
data("transplant", package = "BetaDanish")

# Fit the model to censored data
fit_censored <- fit_betadanish(survival::Surv(time, status) ~ 1, data = transplant)
summary(fit_censored)

# Plot the Kaplan-Meier curve overlaid with the Beta-Danish fit
plot(fit_censored, type = "survival")
```

## 5. Advanced Modeling: Cure Rates

In many clinical datasets (like the `transplant` data), a proportion of patients may be "cured" and will never experience the event. Standard survival models force the survival curve to zero, which misrepresents the data.

The `BetaDanish` package provides the `fit_bd_cure()` function to fit both **Mixture** and **Promotion-Time (Non-Mixture)** cure models.

```r
# Fit a mixture cure model
# Latency (time to event for susceptible) has no covariates (~ 1)
# Incidence (probability of being susceptible) depends on treatment group (~ group)
cure_fit <- fit_bd_cure(
  formula_aft = survival::Surv(time, status) ~ 1,
  formula_cure = ~ group,
  data = transplant,
  type = "mixture"
)

summary(cure_fit)
```

## 6. Automated Benchmarking

To justify the use of the Beta-Danish distribution, you can benchmark it against classical distributions (Weibull, Gamma, Log-Normal, etc.) using the `compare_distributions()` function. *(Note: This requires the `flexsurv` package).* 

```r
# Returns a ranked table of AIC, BIC, and Log-Likelihoods
compare_distributions(fit_full)
```

## 7. Conclusion

The `BetaDanish` package offers a robust, flexible, and user-friendly environment for advanced survival analysis. By unifying standard MLE fitting, comprehensive diagnostics, and advanced modules (AFT, Cure, Competing Risks) under a single framework, it serves as a powerful tool for statisticians and applied researchers alike.

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plotting.R
\name{plot.betadanish}
\alias{plot.betadanish}
\title{Plot Diagnostics for Beta-Danish Fit}
\usage{
\method{plot}{betadanish}(x, type = c("survival", "hazard", "density", "pp", "qq", "all"), ...)
}
\arguments{
\item{x}{A fitted `betadanish` object.}

\item{type}{Character string specifying the plot type: `"survival"`, `"hazard"`,
`"density"`, `"pp"`, `"qq"`, or `"all"`.}

\item{...}{Additional arguments passed to the base `plot` function.}
}
\value{
Invisibly returns the input betadanish object. Called mainly for its side effect of producing diagnostic plots.
}
\description{
Generates diagnostic plots for a fitted Beta-Danish model, including survival,
hazard, density, PP, and QQ plots.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/report_betadanish.R
\name{report_betadanish}
\alias{report_betadanish}
\title{Create a compact report from a BetaDanish model fit}
\usage{
report_betadanish(fit)
}
\arguments{
\item{fit}{A fitted BetaDanish model object.}
}
\value{
A list containing model summary information.
}
\description{
Create a compact report from a BetaDanish model fit
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/summary_methods.R
\name{print.betadanish}
\alias{print.betadanish}
\title{Print Method for Beta-Danish Fit}
\usage{
\method{print}{betadanish}(x, ...)
}
\arguments{
\item{x}{An object of class `betadanish`.}

\item{...}{Further arguments passed to or from other methods.}
}
\value{
Invisibly returns the input betadanish object. Called mainly for its side effect of printing the fitted model summary.
}
\description{
Print Method for Beta-Danish Fit
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/compare_models.R
\name{compare_distributions}
\alias{compare_distributions}
\title{Compare Beta-Danish with Standard Distributions}
\usage{
compare_distributions(object)
}
\arguments{
\item{object}{A fitted `betadanish` object.}
}
\value{
A ranked data frame of model comparisons.
}
\description{
Fits standard lifetime distributions (Weibull, Log-Normal, Log-Logistic, Gamma, 
Exponential) using the `flexsurv` package and compares them to the Beta-Danish fit.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/BetaDanish-package.R
\docType{package}
\name{BetaDanish-package}
\alias{BetaDanish-package}
\title{BetaDanish: The Beta-Danish Distribution for Lifetime Data Analysis}
\description{
Implements the four-parameter Beta-Danish distribution and its three-parameter submodel for survival and reliability analysis, based on Ahmad and Danish (2025) \doi{10.2478/jamsi-2025-0010}. Provides functions for density, distribution, quantile, hazard, and random generation. Includes maximum likelihood estimation for complete and right-censored data, goodness-of-fit assessment, comparison with standard lifetime distributions, and publication-quality visualizations. Advanced modules support Accelerated Failure Time (AFT) regression, mixture and promotion-time cure models, and competing risks analysis.
}
\details{
The `BetaDanish` package provides a comprehensive suite of tools for survival 
and reliability analysis using the Beta-Danish distribution. It includes core 
mathematical functions (density, distribution, quantile, random generation, 
and hazard), robust Maximum Likelihood Estimation (MLE) for both complete and 
right-censored data, and advanced modeling capabilities including Accelerated 
Failure Time (AFT) regression, cure-rate models, and competing risks analysis.
}
\references{
Ahmad, B. (2026). Modeling Diverse Survival Patterns: The Development and 
Characterization of a New Four-Parameter Lifetime Distribution (Ph.D. Thesis). 
Allama Iqbal Open University, Islamabad.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://github.com/bilal-aiou/BetaDanish}
  \item Report bugs at \url{https://github.com/bilal-aiou/BetaDanish/issues}
}

}
\author{
\strong{Maintainer}: Bilal Ahmad \email{bilalahmad.imcbh9@gmail.com}

Authors:
\itemize{
  \item Bilal Ahmad \email{bilalahmad.imcbh9@gmail.com}
  \item Muhammad Yameen Danish \email{yameen.danish@aiou.edu.pk}
}

}
\keyword{internal}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{transplant}
\alias{transplant}
\title{Bone Marrow Transplant Survival}
\format{
A data frame with 91 rows and 3 columns:
\describe{
  \item{time}{Survival time in days}
  \item{status}{Event indicator (1 = death/relapse, 0 = censored)}
  \item{group}{Treatment group (0 = Allogeneic, 1 = Autologous)}
}
}
\source{
Klein, J. P., & Moeschberger, M. L. (2003). Survival Analysis: Techniques for Censored and Truncated Data (2nd ed.). Springer.
}
\usage{
transplant
}
\description{
Survival times for 91 patients with refractory acute lymphoblastic leukemia
who received either an allogeneic or autologous bone marrow transplant.
This dataset includes right-censoring and a treatment covariate, making it
ideal for demonstrating cure-rate models and AFT regression.
}
\examples{
data(transplant)
\donttest{
# Fit a model with a covariate
fit <- fit_bd_aft(survival::Surv(time, status) ~ group, data = transplant)
}
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/compare_models.R
\name{gof_betadanish}
\alias{gof_betadanish}
\title{Goodness-of-Fit Statistics for Beta-Danish Models}
\usage{
gof_betadanish(object)
}
\arguments{
\item{object}{A fitted `betadanish` object.}
}
\value{
A list containing the Information Criteria and the K-S statistic.
}
\description{
Computes Information Criteria (AIC, BIC, HQIC, AICC) and the Kolmogorov-Smirnov 
(K-S) statistic for a fitted Beta-Danish model.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/summary_methods.R
\name{print.summary.betadanish}
\alias{print.summary.betadanish}
\title{Print Summary Method for Beta-Danish Fit}
\usage{
\method{print}{summary.betadanish}(x, ...)
}
\arguments{
\item{x}{An object of class `summary.betadanish`.}

\item{...}{Further arguments passed to or from other methods.}
}
\value{
Invisibly returns the input summary.betadanish object. Called mainly for its side effect of printing the coefficient table and fit statistics.
}
\description{
Print Summary Method for Beta-Danish Fit
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{aarset}
\alias{aarset}
\title{Aarset Device Failure Times}
\format{
A data frame with 50 rows and 2 columns:
\describe{
  \item{time}{Failure time}
  \item{status}{Event indicator (1 = event occurred)}
}
}
\source{
Aarset, M. V. (1987). How to Identify a Bathtub Hazard Rate. IEEE Transactions on Reliability, R-36(1), 106-108.
}
\usage{
aarset
}
\description{
Times to failure of 50 devices, exhibiting a classic bathtub-shaped hazard rate.
This is a standard benchmark dataset in reliability engineering.
}
\examples{
data(aarset)
\donttest{
fit <- fit_betadanish(survival::Surv(time, status) ~ 1, data = aarset)
plot(fit, type = "hazard")
}
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{brain_cancer}
\alias{brain_cancer}
\title{Brain Cancer Survival Data}
\format{
A data frame with 500 rows and 16 columns:
\describe{
  \item{ID}{Patient identifier}
  \item{Gender}{Patient gender (1 = Male, 0 = Female)}
  \item{Age}{Age group (1 = Young, 2 = Middle, 3 = Old)}
  \item{Area}{Geographic area (1 = Urban, 0 = Rural)}
  \item{FH}{Family history of cancer (1 = Yes, 0 = No)}
  \item{CMH}{Comorbid history (1 = Yes, 0 = No)}
  \item{Grade}{Tumor grade (1 = I/II, 2 = III, 3 = IV)}
  \item{Surgery}{Surgical intervention (1 = Yes, 0 = No)}
  \item{Radiotherapy}{Radiotherapy treatment (1 = Yes, 0 = No)}
  \item{Chemotherapy}{Chemotherapy treatment (1 = Yes, 0 = No)}
  \item{Treatment}{Treatment type}
  \item{Morphology}{Tumor morphology}
  \item{Survstatus}{Survival status (1 = Event/Death, 0 = Censored)}
  \item{Survtime}{Survival time in months}
  \item{Types}{Tumor types classification}
  \item{Morphology1}{Alternative morphology classification}
}
}
\source{
Atomic Energy Cancer Hospital (NORI), Islamabad, Pakistan.
}
\usage{
brain_cancer
}
\description{
A comprehensive dataset of 500 brain cancer patients, including survival times,
censoring status, and multiple clinical covariates. This dataset was used to
demonstrate Accelerated Failure Time (AFT) regression and Cure-Rate models
using the Beta-Danish distribution.
}
\examples{
data(brain_cancer)
\donttest{
# Fit an AFT model using the brain cancer data
fit <- fit_bd_aft(survival::Surv(Survtime, Survstatus) ~ Age + Grade + Surgery,
                  data = brain_cancer, n_starts = 2)
summary(fit)
}
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{melanoma}
\alias{melanoma}
\title{Malignant Melanoma Survival After Surgery}
\format{
A data frame with 205 rows and 6 columns:
\describe{
  \item{time}{Survival time in days}
  \item{status}{Event indicator (1 = died from melanoma, 0 = alive, 2 = other death)}
  \item{thickness}{Tumor thickness in mm}
  \item{sex}{Patient sex (1 = male, 0 = female)}
  \item{age}{Patient age in years}
  \item{ulcer}{Ulceration indicator (1 = present, 0 = absent)}
  \item{year}{Year of operation}
}
}
\source{
Andersen, P. K., Borgan, O., Gill, R. D., & Keiding, N. (1993). Statistical Models Based on Counting Processes. Springer.
}
\usage{
melanoma
}
\description{
Survival times for 205 patients with malignant melanoma after surgery.
This rich clinical dataset includes multiple covariates and heavy censoring.
}
\examples{
data(melanoma)
\donttest{
# Treat status 1 as event, others as censored
melanoma$event <- ifelse(melanoma$status == 1, 1, 0)
fit <- fit_betadanish(survival::Surv(time, event) ~ age + thickness, data = melanoma)
}
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/summary_methods.R
\name{vcov.betadanish}
\alias{vcov.betadanish}
\title{Extract Variance-Covariance Matrix}
\usage{
\method{vcov}{betadanish}(object, ...)
}
\arguments{
\item{object}{An object of class `betadanish`.}

\item{...}{Further arguments passed to or from other methods.}
}
\value{
A numeric variance-covariance matrix for the estimated model parameters.
}
\description{
Extract Variance-Covariance Matrix
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{remission}
\alias{remission}
\title{Bladder Cancer Remission Times}
\format{
A data frame with 128 rows and 2 columns:
\describe{
  \item{time}{Remission time in months}
  \item{status}{Event indicator (1 = event occurred)}
}
}
\source{
Lee, E. T., & Wang, J. W. (2003). Statistical Methods for Survival Data Analysis (3rd ed.). Wiley.
}
\usage{
remission
}
\description{
Remission times (in months) for 128 bladder cancer patients. This is a
complete (uncensored) sample widely used in lifetime distribution literature
to demonstrate decreasing or right-skewed hazard rates.
}
\examples{
data(remission)
\donttest{
fit <- fit_betadanish(survival::Surv(time, status) ~ 1, data = remission)
summary(fit)
}
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/report.R
\name{analyze_betadanish}
\alias{analyze_betadanish}
\title{Comprehensive Beta-Danish Analysis Pipeline}
\usage{
analyze_betadanish(file, time_col, status_col = NULL)
}
\arguments{
\item{file}{Path to the CSV or Excel file containing the data.}

\item{time_col}{Name of the time column.}

\item{status_col}{Name of the status column (optional).}
}
\value{
Invisibly returns a list containing the fitted full model and submodel objects. The function is mainly called for its side effects of printing an analysis report and producing diagnostic plots.
}
\description{
Runs a complete end-to-end analysis: reads data, fits the 4-parameter and
3-parameter models, compares them, benchmarks against standard distributions,
and generates diagnostic plots.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/simulation.R
\name{simulate_bd_cure_data}
\alias{simulate_bd_cure_data}
\title{Simulate Beta-Danish Cure Data}
\usage{
simulate_bd_cure_data(
  n,
  type = c("mixture", "promotion"),
  a = 1,
  b = 2,
  c = 1.5,
  delta,
  gamma,
  X,
  Z,
  target_censor = 0.3,
  seed = NULL
)
}
\arguments{
\item{n}{Integer; number of observations.}

\item{type}{Character; `"mixture"` or `"promotion"`.}

\item{a, b, c}{Numeric; baseline shape parameters.}

\item{delta}{Numeric vector; coefficients for the latency scale `k`.}

\item{gamma}{Numeric vector; coefficients for the incidence/cure component.}

\item{X}{Matrix; design matrix for latency (must match length of `delta`).}

\item{Z}{Matrix; design matrix for incidence (must match length of `gamma`).}

\item{target_censor}{Numeric; target proportion of censoring to calibrate the
exponential censoring rate. Default is 0.3.}

\item{seed}{Integer; optional seed.}
}
\value{
A list containing the simulated `data` (time, status), the `cured`
  indicator, and the true parameters.
}
\description{
Generates synthetic survival data from a Beta-Danish mixture or promotion-time
cure model, incorporating covariates.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cure_models.R
\name{fit_bd_cure}
\alias{fit_bd_cure}
\title{Fit Beta-Danish Cure Models}
\usage{
fit_bd_cure(
  formula_aft,
  formula_cure,
  data,
  type = c("mixture", "promotion"),
  n_starts = 10,
  method = "BFGS"
)
}
\arguments{
\item{formula_aft}{A formula for the latency component (e.g., `Surv(time, status) ~ age`).}

\item{formula_cure}{A one-sided formula for the incidence/cure component (e.g., `~ treatment`).}

\item{data}{A data frame containing the variables.}

\item{type}{Character; either `"mixture"` or `"promotion"`.}

\item{n_starts}{Integer; number of random starts for optimization.}

\item{method}{Optimization method passed to `maxLik`.}
}
\value{
An object of class `bd_cure`.
}
\description{
Fits mixture and promotion-time (non-mixture) cure models using the 
Beta-Danish AFT baseline.
}
\details{
In the **mixture** model, the population is split into susceptible and cured 
fractions. The susceptible probability is modeled via logistic regression: 
`pi = exp(Z %*% gamma) / (1 + exp(Z %*% gamma))`.

In the **promotion-time** (non-mixture) model, the cure fraction is derived 
from a latent Poisson process of clonogenic cells: `theta = exp(Z %*% gamma)`. 
The cure fraction is `exp(-theta)`.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/aft_models.R
\name{fit_bd_aft}
\alias{fit_bd_aft}
\title{Fit Beta-Danish AFT Regression Model}
\usage{
fit_bd_aft(formula, data, n_starts = 10, method = "BFGS")
}
\arguments{
\item{formula}{A survival formula (e.g., `Surv(time, status) ~ age + treatment`).}

\item{data}{A data frame containing the variables.}

\item{n_starts}{Integer; number of random starts for optimization.}

\item{method}{Optimization method passed to `maxLik`.}
}
\value{
An object of class `bd_aft`.
}
\description{
Fits an Accelerated Failure Time (AFT) regression model using the
Complementary Exponentiated Danish (CED) baseline (Beta-Danish with a=1).
}
\details{
To ensure identifiability, the shape parameter `a` is fixed to 1. The scale
parameter `k` is linked to covariates via `k_i = exp(X_i %*% delta)`.
Positive coefficients in `delta` indicate a larger `k`, which corresponds
to shorter survival times (accelerated failure).
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/simulation.R
\name{simulate_bd_data}
\alias{simulate_bd_data}
\title{Simulate Data from the Beta-Danish Distribution}
\usage{
simulate_bd_data(n, a, b, c, k, censor_rate = 0, seed = NULL)
}
\arguments{
\item{n}{Integer; number of observations to simulate.}

\item{a, b, c, k}{Numeric; parameters of the Beta-Danish distribution.}

\item{censor_rate}{Numeric; rate parameter for the exponential censoring
distribution. If `0` (default), no censoring is applied.}

\item{seed}{Integer; optional seed for reproducibility.}
}
\value{
A data frame with columns `time` and `status`.
}
\description{
Generates synthetic survival data from the Beta-Danish distribution, with
optional right-censoring.
}
\examples{
# Simulate complete data
dat <- simulate_bd_data(n = 100, a = 1.5, b = 2, c = 3, k = 0.5)

# Simulate censored data
dat_cens <- simulate_bd_data(n = 100, a = 1.5, b = 2, c = 3, k = 0.5, censor_rate = 0.1)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/compare_models.R
\name{compare_models}
\alias{compare_models}
\title{Compare Nested Beta-Danish Models}
\usage{
compare_models(full_model, sub_model)
}
\arguments{
\item{full_model}{A fitted 4-parameter `betadanish` object.}

\item{sub_model}{A fitted 3-parameter `betadanish` object.}
}
\value{
A data frame with the test statistic and p-value.
}
\description{
Performs a Likelihood Ratio Test (LRT) between the 4-parameter full model 
and the 3-parameter submodel.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{carbon_fibres}
\alias{carbon_fibres}
\title{Breaking Stress of Carbon Fibres}
\format{
A data frame with 100 rows and 2 columns:
\describe{
  \item{time}{Breaking stress in Gba}
  \item{status}{Event indicator (1 = event occurred)}
}
}
\source{
Nichols, M. D., & Padgett, W. J. (2006). A bootstrap control chart for Weibull percentiles. Quality and Reliability Engineering International, 22(2), 141-151.
}
\usage{
carbon_fibres
}
\description{
Breaking stress (in Gba) of 100 carbon fibre specimens. This dataset exhibits
a unimodal (increasing-then-decreasing) hazard pattern that classical
distributions like the Weibull cannot adequately capture.
}
\examples{
data(carbon_fibres)
\donttest{
fit <- fit_betadanish(survival::Surv(time, status) ~ 1, data = carbon_fibres)
}
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/competing_risks.R
\name{cif_betadanish}
\alias{cif_betadanish}
\title{Compute Cumulative Incidence Function (CIF)}
\usage{
cif_betadanish(fit, tvec, cause_idx)
}
\arguments{
\item{fit}{An object of class `bd_competing`.}

\item{tvec}{Numeric vector of times at which to evaluate the CIF.}

\item{cause_idx}{Integer; the specific cause to evaluate (must match one of
the causes in the fitted model).}
}
\value{
A numeric vector of CIF probabilities corresponding to `tvec`.
}
\description{
Computes the CIF for a specific cause from a fitted Beta-Danish competing
risks model using numerical integration.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fit_models.R
\name{fit_betadanish}
\alias{fit_betadanish}
\title{Fit the Beta-Danish Distribution to Survival Data}
\usage{
fit_betadanish(formula, data, submodel = FALSE, n_starts = 10, method = "BFGS")
}
\arguments{
\item{formula}{A formula object, with the response on the left of a `~` operator,
and the terms on the right. The response must be a survival object as returned
by the `Surv` function. Use `~ 1` for models without covariates.}

\item{data}{A data frame containing the variables named in the formula.}

\item{submodel}{Logical; if `TRUE`, fits the 3-parameter submodel by fixing `a = 1`.}

\item{n_starts}{Integer; the number of random starting points to use for the
optimization to ensure global convergence. Default is 10.}

\item{method}{Character; the optimization method passed to `maxLik`. Default is "BFGS".}
}
\value{
An object of S3 class `"betadanish"`, containing the parameter estimates,
  log-likelihood, variance-covariance matrix, and convergence diagnostics.
}
\description{
Fits the Beta-Danish distribution using Maximum Likelihood Estimation (MLE).
Supports both complete and right-censored data via `survival::Surv` objects.
}
\details{
The optimization is performed on the log-transformed parameters to strictly
enforce positivity constraints. The returned coefficients and variance-covariance
matrix are transformed back to the natural scale using the Delta method.
}
\examples{
\donttest{
# Simulate some data
set.seed(123)
sim_time <- rbetadanish(100, a = 1.5, b = 2, c = 3, k = 0.5)
sim_status <- sample(c(0, 1), 100, replace = TRUE, prob = c(0.2, 0.8))
dat <- data.frame(time = sim_time, status = sim_status)

# Fit the 4-parameter model
fit <- fit_betadanish(survival::Surv(time, status) ~ 1, data = dat)
summary(fit)

# Fit the 3-parameter submodel
fit_sub <- fit_betadanish(survival::Surv(time, status) ~ 1, data = dat, submodel = TRUE)
summary(fit_sub)
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/summary_methods.R
\name{summary.betadanish}
\alias{summary.betadanish}
\title{Summary Method for Beta-Danish Fit}
\usage{
\method{summary}{betadanish}(object, ...)
}
\arguments{
\item{object}{An object of class `betadanish`.}

\item{...}{Further arguments passed to or from other methods.}
}
\value{
An object of class summary.betadanish containing coefficient estimates, standard errors, test statistics, p-values, log-likelihood, and model selection criteria.
}
\description{
Summary Method for Beta-Danish Fit
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/competing_risks.R
\name{fit_bd_competing}
\alias{fit_bd_competing}
\title{Fit Beta-Danish Competing Risks Model}
\usage{
fit_bd_competing(time, cause, n_starts = 5, method = "BFGS")
}
\arguments{
\item{time}{Numeric vector of observed times.}

\item{cause}{Integer vector of event causes. `0` indicates right-censored,
and `1, 2, ..., m` indicate specific event causes.}

\item{n_starts}{Integer; number of random starts for the joint optimization.}

\item{method}{Optimization method passed to `maxLik`.}
}
\value{
An object of class `bd_competing`.
}
\description{
Fits a parametric competing risks model assuming independent latent failure
times, where each cause-specific baseline follows a 4-parameter Beta-Danish
distribution.
}
\details{
Under the assumption of independent latent failure times, the joint likelihood
factorizes. The function first fits independent Beta-Danish models for each
cause (treating other causes as censored) to find robust starting values,
then optimizes the joint likelihood.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_helpers.R
\name{read_survival_data}
\alias{read_survival_data}
\title{Read and Prepare Survival Data}
\usage{
read_survival_data(file, time_col, status_col = NULL, covar_cols = NULL)
}
\arguments{
\item{file}{Character string specifying the path to the file.}

\item{time_col}{Character string specifying the name of the time/survival column.}

\item{status_col}{Character string specifying the name of the event/censoring
indicator column. If `NULL` (default), the function assumes all observations
are uncensored and creates a status column filled with 1s.}

\item{covar_cols}{Character vector specifying the names of covariate columns
to keep. If `NULL` (default), no covariates are kept.}
}
\value{
A clean `data.frame` containing the `time`, `status`, and any
  specified covariates, ready to be passed to `fit_betadanish()`.
}
\description{
A helper function to read survival data from CSV or Excel files and prepare
it for analysis with the Beta-Danish package. It automatically handles missing
status columns by assuming all observations are complete (uncensored).
}
\details{
The function checks the file extension to determine how to read the data.
For `.xlsx` or `.xls` files, the `readxl` package must be installed.
Missing values (`NA`) in the specified columns will cause those rows to be
dropped with a warning.
}
\examples{
tmp <- tempfile(fileext = ".csv")
example_data <- data.frame(
  survival_time = c(5, 8, 12, 16),
  status = c(1, 1, 0, 1)
)
write.csv(example_data, tmp, row.names = FALSE)
dat <- read_survival_data(tmp, time_col = "survival_time", status_col = "status")
unlink(tmp)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dist_functions.R
\name{BetaDanish}
\alias{BetaDanish}
\alias{dbetadanish}
\alias{pbetadanish}
\alias{qbetadanish}
\alias{rbetadanish}
\alias{hbetadanish}
\title{The Beta-Danish Distribution}
\usage{
dbetadanish(x, a, b, c, k, log = FALSE)

pbetadanish(q, a, b, c, k, lower.tail = TRUE, log.p = FALSE)

qbetadanish(p, a, b, c, k, lower.tail = TRUE, log.p = FALSE)

rbetadanish(n, a, b, c, k)

hbetadanish(x, a, b, c, k, log = FALSE)
}
\arguments{
\item{x, q}{Vector of quantiles (time points).}

\item{a}{Shape parameter (beta generator). Set `a = 1` for the 3-parameter submodel.}

\item{b}{Shape parameter (beta generator / tail weight).}

\item{c}{Shape parameter (baseline shape).}

\item{k}{Scale parameter (baseline scale).}

\item{log, log.p}{Logical; if TRUE, probabilities/densities are given as log.}

\item{lower.tail}{Logical; if TRUE (default), probabilities are P[X <= x], otherwise P[X > x].}

\item{p}{Vector of probabilities.}

\item{n}{Number of observations to generate.}
}
\value{
`dbetadanish` gives the density, `pbetadanish` gives the distribution function,
`qbetadanish` gives the quantile function, `hbetadanish` gives the hazard function,
and `rbetadanish` generates random deviates.
}
\description{
Density, distribution function, quantile function, hazard function, and
random generation for the four-parameter Beta-Danish distribution.
}
\details{
The Beta-Danish distribution is a highly flexible lifetime distribution capable
of modeling decreasing, increasing, unimodal, and bathtub-shaped hazard rates.
}
\examples{
# Density
dbetadanish(x = 2, a = 1.5, b = 2, c = 3, k = 0.5)

# CDF
pbetadanish(q = 2, a = 1.5, b = 2, c = 3, k = 0.5)

# Hazard
hbetadanish(x = 2, a = 1.5, b = 2, c = 3, k = 0.5)

# Random generation
rbetadanish(n = 10, a = 1.5, b = 2, c = 3, k = 0.5)

}
\references{
Ahmad, B., & Danish, M. Y. (2026). Development and Characterization of a
Flexible Three-Parameter Lifetime Distribution.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/summary_methods.R
\name{coef.betadanish}
\alias{coef.betadanish}
\title{Extract Coefficients}
\usage{
\method{coef}{betadanish}(object, ...)
}
\arguments{
\item{object}{An object of class `betadanish`.}

\item{...}{Further arguments passed to or from other methods.}
}
\value{
A named numeric vector of maximum likelihood parameter estimates.
}
\description{
Extract Coefficients
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/summary_methods.R
\name{logLik.betadanish}
\alias{logLik.betadanish}
\title{Extract Log-Likelihood}
\usage{
\method{logLik}{betadanish}(object, ...)
}
\arguments{
\item{object}{An object of class `betadanish`.}

\item{...}{Further arguments passed to or from other methods.}
}
\value{
An object of class logLik containing the maximized log-likelihood value, with degrees of freedom and number of observations stored as attributes.
}
\description{
Extract Log-Likelihood
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{leukemia}
\alias{leukemia}
\title{Acute Myelogenous Leukemia Survival}
\format{
A data frame with 23 rows and 3 columns:
\describe{
  \item{time}{Survival time in weeks}
  \item{status}{Event indicator (1 = event, 0 = censored)}
  \item{group}{Treatment group (Maintained vs Non-maintained)}
}
}
\source{
Miller, R. G. (1997). Survival Analysis. Wiley.
}
\usage{
leukemia
}
\description{
Survival times (in weeks) for 23 patients with acute myelogenous leukemia.
A classic, small dataset perfect for fast testing of censored data workflows.
}
\examples{
data(leukemia)
fit <- fit_betadanish(survival::Surv(time, status) ~ 1, data = leukemia)
}
\keyword{datasets}
